# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: inventory.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0finventory.proto\x12\x14opi_api.inventory.v1\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\"P\n\x08\x42IOSInfo\x12\x16\n\x06vendor\x18\x01 \x01(\tR\x06vendor\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\x12\x12\n\x04\x64\x61te\x18\x03 \x01(\tR\x04\x64\x61te\"\xb5\x01\n\nSystemInfo\x12\x16\n\x06\x66\x61mily\x18\x01 \x01(\tR\x06\x66\x61mily\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x16\n\x06vendor\x18\x03 \x01(\tR\x06vendor\x12#\n\rserial_number\x18\x04 \x01(\tR\x0cserialNumber\x12\x12\n\x04uuid\x18\x05 \x01(\tR\x04uuid\x12\x10\n\x03sku\x18\x06 \x01(\tR\x03sku\x12\x18\n\x07version\x18\x07 \x01(\tR\x07version\"\xc0\x01\n\x0b\x43hassisInfo\x12\x1b\n\tasset_tag\x18\x01 \x01(\tR\x08\x61ssetTag\x12#\n\rserial_number\x18\x02 \x01(\tR\x0cserialNumber\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12)\n\x10type_description\x18\x04 \x01(\tR\x0ftypeDescription\x12\x16\n\x06vendor\x18\x05 \x01(\tR\x06vendor\x12\x18\n\x07version\x18\x06 \x01(\tR\x07version\"\x9d\x01\n\rBaseboardInfo\x12\x1b\n\tasset_tag\x18\x01 \x01(\tR\x08\x61ssetTag\x12#\n\rserial_number\x18\x02 \x01(\tR\x0cserialNumber\x12\x16\n\x06vendor\x18\x03 \x01(\tR\x06vendor\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\x12\x18\n\x07product\x18\x05 \x01(\tR\x07product\"O\n\x07\x43PUInfo\x12\x1f\n\x0btotal_cores\x18\x01 \x01(\x05R\ntotalCores\x12#\n\rtotal_threads\x18\x02 \x01(\x05R\x0ctotalThreads\"l\n\nMemoryInfo\x12\x30\n\x14total_physical_bytes\x18\x01 \x01(\x03R\x12totalPhysicalBytes\x12,\n\x12total_usable_bytes\x18\x02 \x01(\x03R\x10totalUsableBytes\"\xe0\x01\n\x0ePCIeDeviceInfo\x12\x16\n\x06\x64river\x18\x01 \x01(\tR\x06\x64river\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\x12\x16\n\x06vendor\x18\x03 \x01(\tR\x06vendor\x12\x18\n\x07product\x18\x04 \x01(\tR\x07product\x12\x1a\n\x08revision\x18\x05 \x01(\tR\x08revision\x12\x1c\n\tsubsystem\x18\x06 \x01(\tR\tsubsystem\x12\x14\n\x05\x63lass\x18\x07 \x01(\tR\x05\x63lass\x12\x1a\n\x08subclass\x18\x08 \x01(\tR\x08subclass\"R\n\x13GetInventoryRequest\x12;\n\x04name\x18\x01 \x01(\tB\'\xe2\x41\x01\x02\xfa\x41 \n\x1eopi_api.inventory.v1/InventoryR\x04name\"\xa8\x03\n\tInventory\x12\x32\n\x04\x62ios\x18\x01 \x01(\x0b\x32\x1e.opi_api.inventory.v1.BIOSInfoR\x04\x62ios\x12\x38\n\x06system\x18\x02 \x01(\x0b\x32 .opi_api.inventory.v1.SystemInfoR\x06system\x12\x41\n\tbaseboard\x18\x03 \x01(\x0b\x32#.opi_api.inventory.v1.BaseboardInfoR\tbaseboard\x12;\n\x07\x63hassis\x18\x04 \x01(\x0b\x32!.opi_api.inventory.v1.ChassisInfoR\x07\x63hassis\x12;\n\tprocessor\x18\x05 \x01(\x0b\x32\x1d.opi_api.inventory.v1.CPUInfoR\tprocessor\x12\x38\n\x06memory\x18\x06 \x01(\x0b\x32 .opi_api.inventory.v1.MemoryInfoR\x06memory\x12\x36\n\x03pci\x18\x07 \x03(\x0b\x32$.opi_api.inventory.v1.PCIeDeviceInfoR\x03pci2\xa2\x01\n\x10InventoryService\x12\x8d\x01\n\x0cGetInventory\x12).opi_api.inventory.v1.GetInventoryRequest\x1a\x1f.opi_api.inventory.v1.Inventory\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$\x12\"/v1/{name=inventory/*/inventory/*}B[\n\x14opi_api.inventory.v1B\x0eInventoryProtoP\x01Z1github.com/opiproject/opi-api/inventory/v1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'inventory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024opi_api.inventory.v1B\016InventoryProtoP\001Z1github.com/opiproject/opi-api/inventory/v1/gen/go'
  _globals['_GETINVENTORYREQUEST'].fields_by_name['name']._options = None
  _globals['_GETINVENTORYREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A \n\036opi_api.inventory.v1/Inventory'
  _globals['_INVENTORYSERVICE'].methods_by_name['GetInventory']._options = None
  _globals['_INVENTORYSERVICE'].methods_by_name['GetInventory']._serialized_options = b'\332A\004name\202\323\344\223\002$\022\"/v1/{name=inventory/*/inventory/*}'
  _globals['_BIOSINFO']._serialized_start=156
  _globals['_BIOSINFO']._serialized_end=236
  _globals['_SYSTEMINFO']._serialized_start=239
  _globals['_SYSTEMINFO']._serialized_end=420
  _globals['_CHASSISINFO']._serialized_start=423
  _globals['_CHASSISINFO']._serialized_end=615
  _globals['_BASEBOARDINFO']._serialized_start=618
  _globals['_BASEBOARDINFO']._serialized_end=775
  _globals['_CPUINFO']._serialized_start=777
  _globals['_CPUINFO']._serialized_end=856
  _globals['_MEMORYINFO']._serialized_start=858
  _globals['_MEMORYINFO']._serialized_end=966
  _globals['_PCIEDEVICEINFO']._serialized_start=969
  _globals['_PCIEDEVICEINFO']._serialized_end=1193
  _globals['_GETINVENTORYREQUEST']._serialized_start=1195
  _globals['_GETINVENTORYREQUEST']._serialized_end=1277
  _globals['_INVENTORY']._serialized_start=1280
  _globals['_INVENTORY']._serialized_end=1704
  _globals['_INVENTORYSERVICE']._serialized_start=1707
  _globals['_INVENTORYSERVICE']._serialized_end=1869
# @@protoc_insertion_point(module_scope)
