# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: networkinterfaces.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
import networkvlan_pb2 as networkvlan__pb2
import networkethernet_pb2 as networkethernet__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17networkinterfaces.proto\x12%opi_api.network.opinetcommon.v1alpha1\x1a\x12networktypes.proto\x1a\x11networkvlan.proto\x1a\x15networkethernet.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\xc9\x02\n\x06\x43onfig\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x04name\x12N\n\x04type\x18\x02 \x01(\x0e\x32\x34.opi_api.network.opinetcommon.v1alpha1.InterfaceTypeB\x04\xe2\x41\x01\x02R\x04type\x12\x16\n\x03mtu\x18\x03 \x01(\rB\x04\xe2\x41\x01\x02R\x03mtu\x12)\n\rloopback_mode\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x02R\x0cloopbackMode\x12&\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x04\xe2\x41\x01\x02R\x0b\x64\x65scription\x12\x1e\n\x07\x65nabled\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x02R\x07\x65nabled\x12J\n\x04tpid\x18\x07 \x01(\x0e\x32\x30.opi_api.network.opinetcommon.v1alpha1.TpidTypesB\x04\xe2\x41\x01\x01R\x04tpid\"\x98\x06\n\x08\x43ounters\x12!\n\trx_octets\x18\x01 \x01(\x04\x42\x04\xe2\x41\x01\x03R\x08rxOctets\x12#\n\nrx_packets\x18\x02 \x01(\x04\x42\x04\xe2\x41\x01\x03R\trxPackets\x12,\n\x0frx_unicast_pkts\x18\x03 \x01(\x04\x42\x04\xe2\x41\x01\x03R\rrxUnicastPkts\x12\x30\n\x11rx_broadcast_pkts\x18\x04 \x01(\x04\x42\x04\xe2\x41\x01\x03R\x0frxBroadcastPkts\x12\x30\n\x11rx_multicast_pkts\x18\x05 \x01(\x04\x42\x04\xe2\x41\x01\x03R\x0frxMulticastPkts\x12%\n\x0brx_discards\x18\x06 \x01(\x04\x42\x04\xe2\x41\x01\x03R\nrxDiscards\x12!\n\trx_errors\x18\x07 \x01(\x04\x42\x04\xe2\x41\x01\x03R\x08rxErrors\x12\x30\n\x11rx_unknown_protos\x18\x08 \x01(\x04\x42\x04\xe2\x41\x01\x03R\x0frxUnknownProtos\x12(\n\rrx_fcs_errors\x18\t \x01(\x04\x42\x04\xe2\x41\x01\x03R\x0brxFcsErrors\x12#\n\nout_octets\x18\n \x01(\x04\x42\x04\xe2\x41\x01\x03R\toutOctets\x12%\n\x0bout_packets\x18\x0b \x01(\x04\x42\x04\xe2\x41\x01\x03R\noutPackets\x12.\n\x10out_unicast_pkts\x18\x0c \x01(\x04\x42\x04\xe2\x41\x01\x03R\x0eoutUnicastPkts\x12\x32\n\x12out_broadcast_pkts\x18\r \x01(\x04\x42\x04\xe2\x41\x01\x03R\x10outBroadcastPkts\x12\x32\n\x12out_multicast_pkts\x18\x0e \x01(\x04\x42\x04\xe2\x41\x01\x03R\x10outMulticastPkts\x12\'\n\x0cout_discards\x18\x0f \x01(\x04\x42\x04\xe2\x41\x01\x03R\x0boutDiscards\x12#\n\nout_errors\x18\x10 \x01(\x04\x42\x04\xe2\x41\x01\x03R\toutErrors\x12\x35\n\x13\x63\x61rrier_transitions\x18\x11 \x01(\x04\x42\x04\xe2\x41\x01\x03R\x12\x63\x61rrierTransitions\x12#\n\nlast_clear\x18\x12 \x01(\x04\x42\x04\xe2\x41\x01\x03R\tlastClear\"\xf1\x05\n\x05State\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12N\n\x04type\x18\x02 \x01(\x0e\x32\x34.opi_api.network.opinetcommon.v1alpha1.InterfaceTypeB\x04\xe2\x41\x01\x03R\x04type\x12\x16\n\x03mtu\x18\x03 \x01(\rB\x04\xe2\x41\x01\x03R\x03mtu\x12)\n\rloopback_mode\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x03R\x0cloopbackMode\x12&\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x64\x65scription\x12\x1e\n\x07\x65nabled\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x03R\x07\x65nabled\x12\x1e\n\x07ifindex\x18\x07 \x01(\rB\x04\xe2\x41\x01\x03R\x07ifindex\x12X\n\x0b\x61\x64min_state\x18\x08 \x01(\x0e\x32\x31.opi_api.network.opinetcommon.v1alpha1.AdminStateB\x04\xe2\x41\x01\x03R\nadminState\x12U\n\noper_state\x18\t \x01(\x0e\x32\x30.opi_api.network.opinetcommon.v1alpha1.OperStateB\x04\xe2\x41\x01\x03R\toperState\x12%\n\x0blast_change\x18\n \x01(\x04\x42\x04\xe2\x41\x01\x03R\nlastChange\x12\x1e\n\x07logical\x18\x0b \x01(\x08\x42\x04\xe2\x41\x01\x03R\x07logical\x12$\n\nmanagement\x18\x0c \x01(\x08\x42\x04\xe2\x41\x01\x03R\nmanagement\x12\x16\n\x03\x63pu\x18\r \x01(\x08\x42\x04\xe2\x41\x01\x03R\x03\x63pu\x12Q\n\x08\x63ounters\x18\x0e \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.CountersB\x04\xe2\x41\x01\x03R\x08\x63ounters\x12J\n\x04tpid\x18\x0f \x01(\x0e\x32\x30.opi_api.network.opinetcommon.v1alpha1.TpidTypesB\x04\xe2\x41\x01\x03R\x04tpid\"\xfd\x0b\n\x0cNetInterface\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12K\n\x06\x63onfig\x18\x02 \x01(\x0b\x32-.opi_api.network.opinetcommon.v1alpha1.ConfigB\x04\xe2\x41\x01\x02R\x06\x63onfig\x12H\n\x05state\x18\x03 \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.StateB\x04\xe2\x41\x01\x03R\x05state\x12^\n\x08holdtime\x18\x04 \x01(\x0b\x32<.opi_api.network.opinetcommon.v1alpha1.NetInterface.HoldTimeB\x04\xe2\x41\x01\x01R\x08holdtime\x12m\n\rsubinterfaces\x18\x05 \x01(\x0b\x32\x41.opi_api.network.opinetcommon.v1alpha1.NetInterface.SubinterfacesB\x04\xe2\x41\x01\x01R\rsubinterfaces\x12S\n\x08\x65thernet\x18\x06 \x01(\x0b\x32\x31.opi_api.network.opinetcommon.v1alpha1.EthernetIfB\x04\xe2\x41\x01\x01R\x08\x65thernet\x1a\xe2\x02\n\x08HoldTime\x12n\n\x0bhold_config\x18\x01 \x01(\x0b\x32G.opi_api.network.opinetcommon.v1alpha1.NetInterface.HoldTime.HoldConfigB\x04\xe2\x41\x01\x01R\nholdConfig\x12k\n\nhold_state\x18\x02 \x01(\x0b\x32\x46.opi_api.network.opinetcommon.v1alpha1.NetInterface.HoldTime.HoldStateB\x04\xe2\x41\x01\x03R\tholdState\x1a<\n\nHoldConfig\x12\x14\n\x02up\x18\x01 \x01(\rB\x04\xe2\x41\x01\x01R\x02up\x12\x18\n\x04\x64own\x18\x02 \x01(\rB\x04\xe2\x41\x01\x01R\x04\x64own\x1a;\n\tHoldState\x12\x14\n\x02up\x18\x01 \x01(\rB\x04\xe2\x41\x01\x03R\x02up\x12\x18\n\x04\x64own\x18\x02 \x01(\rB\x04\xe2\x41\x01\x03R\x04\x64own\x1a\xc2\x04\n\rSubinterfaces\x12x\n\x0csubinterface\x18\x02 \x03(\x0b\x32N.opi_api.network.opinetcommon.v1alpha1.NetInterface.Subinterfaces.SubinterfaceB\x04\xe2\x41\x01\x01R\x0csubinterface\x1a\xb6\x03\n\x0cSubinterface\x12\x1a\n\x05index\x18\x01 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x05index\x12\x83\x01\n\x0csubif_config\x18\x02 \x01(\x0b\x32Z.opi_api.network.opinetcommon.v1alpha1.NetInterface.Subinterfaces.Subinterface.SubifConfigB\x04\xe2\x41\x01\x01R\x0bsubifConfig\x12H\n\x05state\x18\x03 \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.StateB\x04\xe2\x41\x01\x03R\x05state\x12G\n\x04vlan\x18\x04 \x01(\x0b\x32-.opi_api.network.opinetcommon.v1alpha1.VlanIfB\x04\xe2\x41\x01\x01R\x04vlan\x1aq\n\x0bSubifConfig\x12\x1a\n\x05index\x18\x01 \x01(\x04\x42\x04\xe2\x41\x01\x01R\x05index\x12&\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0b\x64\x65scription\x12\x1e\n\x07\x65nabled\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x07\x65nabled:n\xea\x41k\n2opi_api.network.opinetcommon.v1alpha1/NetInterface\x12\x18netInterface/{interface}*\rnetInterfaces2\x0cnetInterface\"T\n\x16GetNetInterfaceRequest\x12:\n\x04name\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.network.v1/InterfacesR\x04name\"\xa2\x01\n\x18ListNetInterfacesRequest\x12>\n\x06parent\x18\x01 \x01(\tB&\xe2\x41\x01\x02\xfa\x41\x1f\n\x1dopi_api.network.v1/InterfacesR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x9f\x01\n\x19ListNetInterfacesResponse\x12Z\n\x0enet_interfaces\x18\x01 \x03(\x0b\x32\x33.opi_api.network.opinetcommon.v1alpha1.NetInterfaceR\rnetInterfaces\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xe9\x01\n\x19UpdateNetInterfaceRequest\x12^\n\rnet_interface\x18\x01 \x01(\x0b\x32\x33.opi_api.network.opinetcommon.v1alpha1.NetInterfaceB\x04\xe2\x41\x01\x02R\x0cnetInterface\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing*i\n\rInterfaceType\x12\x1e\n\x1aINTERFACE_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17INTERFACE_TYPE_ETHERNET\x10\x01\x12\x1b\n\x17INTERFACE_TYPE_LOOPBACK\x10\x02*\xd4\x01\n\tOperState\x12\x1a\n\x16OPER_STATE_UNSPECIFIED\x10\x00\x12\x11\n\rOPER_STATE_UP\x10\x02\x12\x13\n\x0fOPER_STATE_DOWN\x10\x03\x12\x16\n\x12OPER_STATE_TESTING\x10\x04\x12\x16\n\x12OPER_STATE_UNKNOWN\x10\x05\x12\x16\n\x12OPER_STATE_DORMANT\x10\x06\x12\x1a\n\x16OPER_STATE_NOT_PRESENT\x10\x07\x12\x1f\n\x1bOPER_STATE_LOWER_LAYER_DOWN\x10\x08\x32\x88\x05\n\x13NetInterfaceService\x12\xb9\x01\n\x0fGetNetInterface\x12=.opi_api.network.opinetcommon.v1alpha1.GetNetInterfaceRequest\x1a\x33.opi_api.network.opinetcommon.v1alpha1.NetInterface\"2\xda\x41\x04name\x82\xd3\xe4\x93\x02%\x12#/v1/{name=interfaces/*/interface/*}\x12\xc0\x01\n\x11ListNetInterfaces\x12?.opi_api.network.opinetcommon.v1alpha1.ListNetInterfacesRequest\x1a@.opi_api.network.opinetcommon.v1alpha1.ListNetInterfacesResponse\"(\xda\x41\x06parent\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=interfaces}\x12\xf1\x01\n\x12UpdateNetInterface\x12@.opi_api.network.opinetcommon.v1alpha1.UpdateNetInterfaceRequest\x1a\x33.opi_api.network.opinetcommon.v1alpha1.NetInterface\"d\xda\x41\x19net_interface,update_mask\x82\xd3\xe4\x93\x02\x42\x32\x31/v1/{net_interface.name=interfaces/*/interface/*}:\rnet_interfaceB\x85\x01\n%opi_api.network.opinetcommon.v1alpha1B\x16NetworkInterfacesProtoP\x01ZBgithub.com/opiproject/opi-api/network/opinetcommon/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'networkinterfaces_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%opi_api.network.opinetcommon.v1alpha1B\026NetworkInterfacesProtoP\001ZBgithub.com/opiproject/opi-api/network/opinetcommon/v1alpha1/gen/go'
  _globals['_CONFIG'].fields_by_name['name']._options = None
  _globals['_CONFIG'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_CONFIG'].fields_by_name['type']._options = None
  _globals['_CONFIG'].fields_by_name['type']._serialized_options = b'\342A\001\002'
  _globals['_CONFIG'].fields_by_name['mtu']._options = None
  _globals['_CONFIG'].fields_by_name['mtu']._serialized_options = b'\342A\001\002'
  _globals['_CONFIG'].fields_by_name['loopback_mode']._options = None
  _globals['_CONFIG'].fields_by_name['loopback_mode']._serialized_options = b'\342A\001\002'
  _globals['_CONFIG'].fields_by_name['description']._options = None
  _globals['_CONFIG'].fields_by_name['description']._serialized_options = b'\342A\001\002'
  _globals['_CONFIG'].fields_by_name['enabled']._options = None
  _globals['_CONFIG'].fields_by_name['enabled']._serialized_options = b'\342A\001\002'
  _globals['_CONFIG'].fields_by_name['tpid']._options = None
  _globals['_CONFIG'].fields_by_name['tpid']._serialized_options = b'\342A\001\001'
  _globals['_COUNTERS'].fields_by_name['rx_octets']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_octets']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_packets']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_packets']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_unicast_pkts']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_unicast_pkts']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_broadcast_pkts']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_broadcast_pkts']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_multicast_pkts']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_multicast_pkts']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_discards']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_discards']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_errors']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_errors']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_unknown_protos']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_unknown_protos']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['rx_fcs_errors']._options = None
  _globals['_COUNTERS'].fields_by_name['rx_fcs_errors']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_octets']._options = None
  _globals['_COUNTERS'].fields_by_name['out_octets']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_packets']._options = None
  _globals['_COUNTERS'].fields_by_name['out_packets']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_unicast_pkts']._options = None
  _globals['_COUNTERS'].fields_by_name['out_unicast_pkts']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_broadcast_pkts']._options = None
  _globals['_COUNTERS'].fields_by_name['out_broadcast_pkts']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_multicast_pkts']._options = None
  _globals['_COUNTERS'].fields_by_name['out_multicast_pkts']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_discards']._options = None
  _globals['_COUNTERS'].fields_by_name['out_discards']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['out_errors']._options = None
  _globals['_COUNTERS'].fields_by_name['out_errors']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['carrier_transitions']._options = None
  _globals['_COUNTERS'].fields_by_name['carrier_transitions']._serialized_options = b'\342A\001\003'
  _globals['_COUNTERS'].fields_by_name['last_clear']._options = None
  _globals['_COUNTERS'].fields_by_name['last_clear']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['name']._options = None
  _globals['_STATE'].fields_by_name['name']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['type']._options = None
  _globals['_STATE'].fields_by_name['type']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['mtu']._options = None
  _globals['_STATE'].fields_by_name['mtu']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['loopback_mode']._options = None
  _globals['_STATE'].fields_by_name['loopback_mode']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['description']._options = None
  _globals['_STATE'].fields_by_name['description']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['enabled']._options = None
  _globals['_STATE'].fields_by_name['enabled']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['ifindex']._options = None
  _globals['_STATE'].fields_by_name['ifindex']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['admin_state']._options = None
  _globals['_STATE'].fields_by_name['admin_state']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['oper_state']._options = None
  _globals['_STATE'].fields_by_name['oper_state']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['last_change']._options = None
  _globals['_STATE'].fields_by_name['last_change']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['logical']._options = None
  _globals['_STATE'].fields_by_name['logical']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['management']._options = None
  _globals['_STATE'].fields_by_name['management']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['cpu']._options = None
  _globals['_STATE'].fields_by_name['cpu']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['counters']._options = None
  _globals['_STATE'].fields_by_name['counters']._serialized_options = b'\342A\001\003'
  _globals['_STATE'].fields_by_name['tpid']._options = None
  _globals['_STATE'].fields_by_name['tpid']._serialized_options = b'\342A\001\003'
  _globals['_NETINTERFACE_HOLDTIME_HOLDCONFIG'].fields_by_name['up']._options = None
  _globals['_NETINTERFACE_HOLDTIME_HOLDCONFIG'].fields_by_name['up']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_HOLDTIME_HOLDCONFIG'].fields_by_name['down']._options = None
  _globals['_NETINTERFACE_HOLDTIME_HOLDCONFIG'].fields_by_name['down']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_HOLDTIME_HOLDSTATE'].fields_by_name['up']._options = None
  _globals['_NETINTERFACE_HOLDTIME_HOLDSTATE'].fields_by_name['up']._serialized_options = b'\342A\001\003'
  _globals['_NETINTERFACE_HOLDTIME_HOLDSTATE'].fields_by_name['down']._options = None
  _globals['_NETINTERFACE_HOLDTIME_HOLDSTATE'].fields_by_name['down']._serialized_options = b'\342A\001\003'
  _globals['_NETINTERFACE_HOLDTIME'].fields_by_name['hold_config']._options = None
  _globals['_NETINTERFACE_HOLDTIME'].fields_by_name['hold_config']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_HOLDTIME'].fields_by_name['hold_state']._options = None
  _globals['_NETINTERFACE_HOLDTIME'].fields_by_name['hold_state']._serialized_options = b'\342A\001\003'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG'].fields_by_name['index']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG'].fields_by_name['index']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG'].fields_by_name['description']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG'].fields_by_name['description']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG'].fields_by_name['enabled']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG'].fields_by_name['enabled']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['index']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['index']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['subif_config']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['subif_config']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['state']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['state']._serialized_options = b'\342A\001\003'
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['vlan']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE'].fields_by_name['vlan']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE_SUBINTERFACES'].fields_by_name['subinterface']._options = None
  _globals['_NETINTERFACE_SUBINTERFACES'].fields_by_name['subinterface']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE'].fields_by_name['name']._options = None
  _globals['_NETINTERFACE'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NETINTERFACE'].fields_by_name['config']._options = None
  _globals['_NETINTERFACE'].fields_by_name['config']._serialized_options = b'\342A\001\002'
  _globals['_NETINTERFACE'].fields_by_name['state']._options = None
  _globals['_NETINTERFACE'].fields_by_name['state']._serialized_options = b'\342A\001\003'
  _globals['_NETINTERFACE'].fields_by_name['holdtime']._options = None
  _globals['_NETINTERFACE'].fields_by_name['holdtime']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE'].fields_by_name['subinterfaces']._options = None
  _globals['_NETINTERFACE'].fields_by_name['subinterfaces']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE'].fields_by_name['ethernet']._options = None
  _globals['_NETINTERFACE'].fields_by_name['ethernet']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACE']._options = None
  _globals['_NETINTERFACE']._serialized_options = b'\352Ak\n2opi_api.network.opinetcommon.v1alpha1/NetInterface\022\030netInterface/{interface}*\rnetInterfaces2\014netInterface'
  _globals['_GETNETINTERFACEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNETINTERFACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.network.v1/Interfaces'
  _globals['_LISTNETINTERFACESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTNETINTERFACESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\037\n\035opi_api.network.v1/Interfaces'
  _globals['_LISTNETINTERFACESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNETINTERFACESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNETINTERFACESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNETINTERFACESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENETINTERFACEREQUEST'].fields_by_name['net_interface']._options = None
  _globals['_UPDATENETINTERFACEREQUEST'].fields_by_name['net_interface']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENETINTERFACEREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENETINTERFACEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENETINTERFACEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENETINTERFACEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_NETINTERFACESERVICE'].methods_by_name['GetNetInterface']._options = None
  _globals['_NETINTERFACESERVICE'].methods_by_name['GetNetInterface']._serialized_options = b'\332A\004name\202\323\344\223\002%\022#/v1/{name=interfaces/*/interface/*}'
  _globals['_NETINTERFACESERVICE'].methods_by_name['ListNetInterfaces']._options = None
  _globals['_NETINTERFACESERVICE'].methods_by_name['ListNetInterfaces']._serialized_options = b'\332A\006parent\202\323\344\223\002\031\022\027/v1/{parent=interfaces}'
  _globals['_NETINTERFACESERVICE'].methods_by_name['UpdateNetInterface']._options = None
  _globals['_NETINTERFACESERVICE'].methods_by_name['UpdateNetInterface']._serialized_options = b'\332A\031net_interface,update_mask\202\323\344\223\002B21/v1/{net_interface.name=interfaces/*/interface/*}:\rnet_interface'
  _globals['_INTERFACETYPE']._serialized_start=4345
  _globals['_INTERFACETYPE']._serialized_end=4450
  _globals['_OPERSTATE']._serialized_start=4453
  _globals['_OPERSTATE']._serialized_end=4665
  _globals['_CONFIG']._serialized_start=278
  _globals['_CONFIG']._serialized_end=607
  _globals['_COUNTERS']._serialized_start=610
  _globals['_COUNTERS']._serialized_end=1402
  _globals['_STATE']._serialized_start=1405
  _globals['_STATE']._serialized_end=2158
  _globals['_NETINTERFACE']._serialized_start=2161
  _globals['_NETINTERFACE']._serialized_end=3694
  _globals['_NETINTERFACE_HOLDTIME']._serialized_start=2647
  _globals['_NETINTERFACE_HOLDTIME']._serialized_end=3001
  _globals['_NETINTERFACE_HOLDTIME_HOLDCONFIG']._serialized_start=2880
  _globals['_NETINTERFACE_HOLDTIME_HOLDCONFIG']._serialized_end=2940
  _globals['_NETINTERFACE_HOLDTIME_HOLDSTATE']._serialized_start=2942
  _globals['_NETINTERFACE_HOLDTIME_HOLDSTATE']._serialized_end=3001
  _globals['_NETINTERFACE_SUBINTERFACES']._serialized_start=3004
  _globals['_NETINTERFACE_SUBINTERFACES']._serialized_end=3582
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE']._serialized_start=3144
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE']._serialized_end=3582
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG']._serialized_start=3469
  _globals['_NETINTERFACE_SUBINTERFACES_SUBINTERFACE_SUBIFCONFIG']._serialized_end=3582
  _globals['_GETNETINTERFACEREQUEST']._serialized_start=3696
  _globals['_GETNETINTERFACEREQUEST']._serialized_end=3780
  _globals['_LISTNETINTERFACESREQUEST']._serialized_start=3783
  _globals['_LISTNETINTERFACESREQUEST']._serialized_end=3945
  _globals['_LISTNETINTERFACESRESPONSE']._serialized_start=3948
  _globals['_LISTNETINTERFACESRESPONSE']._serialized_end=4107
  _globals['_UPDATENETINTERFACEREQUEST']._serialized_start=4110
  _globals['_UPDATENETINTERFACEREQUEST']._serialized_end=4343
  _globals['_NETINTERFACESERVICE']._serialized_start=4668
  _globals['_NETINTERFACESERVICE']._serialized_end=5316
# @@protoc_insertion_point(module_scope)
