# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: backend_malloc.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
import opicommon_pb2 as opicommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x62\x61\x63kend_malloc.proto\x12\x12opi_api.storage.v1\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x0fopicommon.proto\"\x96\x02\n\x0cMallocVolume\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12#\n\nblock_size\x18\x02 \x01(\x03\x42\x04\xe2\x41\x01\x02R\tblockSize\x12\'\n\x0c\x62locks_count\x18\x03 \x01(\x03\x42\x04\xe2\x41\x01\x02R\x0b\x62locksCount\x12)\n\rmetadata_size\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0cmetadataSize\x12\x18\n\x04uuid\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01R\x04uuid:Y\xea\x41V\n\x1fopi_api.storage.v1/MallocVolume\x12\x16mallocVolumes/{volume}*\rmallocVolumes2\x0cmallocVolume\"\x98\x01\n\x19\x43reateMallocVolumeRequest\x12K\n\rmalloc_volume\x18\x01 \x01(\x0b\x32 .opi_api.storage.v1.MallocVolumeB\x04\xe2\x41\x01\x02R\x0cmallocVolume\x12.\n\x10malloc_volume_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0emallocVolumeId\"\x84\x01\n\x19\x44\x65leteMallocVolumeRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.storage.v1/MallocVolumeR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xd6\x01\n\x19UpdateMallocVolumeRequest\x12K\n\rmalloc_volume\x18\x01 \x01(\x0b\x32 .opi_api.storage.v1.MallocVolumeB\x04\xe2\x41\x01\x02R\x0cmallocVolume\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"b\n\x18ListMallocVolumesRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x8c\x01\n\x19ListMallocVolumesResponse\x12G\n\x0emalloc_volumes\x18\x01 \x03(\x0b\x32 .opi_api.storage.v1.MallocVolumeR\rmallocVolumes\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"V\n\x16GetMallocVolumeRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.storage.v1/MallocVolumeR\x04name\"X\n\x18StatsMallocVolumeRequest\x12<\n\x04name\x18\x01 \x01(\tB(\xe2\x41\x01\x02\xfa\x41!\n\x1fopi_api.storage.v1/MallocVolumeR\x04name\"R\n\x19StatsMallocVolumeResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats2\xd5\x07\n\x13MallocVolumeService\x12\xb0\x01\n\x12\x43reateMallocVolume\x12-.opi_api.storage.v1.CreateMallocVolumeRequest\x1a .opi_api.storage.v1.MallocVolume\"I\xda\x41\x1emalloc_volume,malloc_volume_id\x82\xd3\xe4\x93\x02\"\"\x11/v1/mallocVolumes:\rmalloc_volume\x12\x86\x01\n\x12\x44\x65leteMallocVolume\x12-.opi_api.storage.v1.DeleteMallocVolumeRequest\x1a\x16.google.protobuf.Empty\")\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/{name=mallocVolumes/*}\x12\xc2\x01\n\x12UpdateMallocVolume\x12-.opi_api.storage.v1.UpdateMallocVolumeRequest\x1a .opi_api.storage.v1.MallocVolume\"[\xda\x41\x19malloc_volume,update_mask\x82\xd3\xe4\x93\x02\x39\x32(/v1/{malloc_volume.name=mallocVolumes/*}:\rmalloc_volume\x12\x8b\x01\n\x11ListMallocVolumes\x12,.opi_api.storage.v1.ListMallocVolumesRequest\x1a-.opi_api.storage.v1.ListMallocVolumesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/mallocVolumes\x12\x8a\x01\n\x0fGetMallocVolume\x12*.opi_api.storage.v1.GetMallocVolumeRequest\x1a .opi_api.storage.v1.MallocVolume\")\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/{name=mallocVolumes/*}\x12\xa1\x01\n\x11StatsMallocVolume\x12,.opi_api.storage.v1.StatsMallocVolumeRequest\x1a-.opi_api.storage.v1.StatsMallocVolumeResponse\"/\xda\x41\x04name\x82\xd3\xe4\x93\x02\"\x12 /v1/{name=mallocVolumes/*}:statsBa\n\x12opi_api.storage.v1B\x12\x42\x61\x63kendMallocProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'backend_malloc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\022BackendMallocProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_MALLOCVOLUME'].fields_by_name['name']._options = None
  _globals['_MALLOCVOLUME'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_MALLOCVOLUME'].fields_by_name['block_size']._options = None
  _globals['_MALLOCVOLUME'].fields_by_name['block_size']._serialized_options = b'\342A\001\002'
  _globals['_MALLOCVOLUME'].fields_by_name['blocks_count']._options = None
  _globals['_MALLOCVOLUME'].fields_by_name['blocks_count']._serialized_options = b'\342A\001\002'
  _globals['_MALLOCVOLUME'].fields_by_name['metadata_size']._options = None
  _globals['_MALLOCVOLUME'].fields_by_name['metadata_size']._serialized_options = b'\342A\001\001'
  _globals['_MALLOCVOLUME'].fields_by_name['uuid']._options = None
  _globals['_MALLOCVOLUME'].fields_by_name['uuid']._serialized_options = b'\342A\001\001'
  _globals['_MALLOCVOLUME']._options = None
  _globals['_MALLOCVOLUME']._serialized_options = b'\352AV\n\037opi_api.storage.v1/MallocVolume\022\026mallocVolumes/{volume}*\rmallocVolumes2\014mallocVolume'
  _globals['_CREATEMALLOCVOLUMEREQUEST'].fields_by_name['malloc_volume']._options = None
  _globals['_CREATEMALLOCVOLUMEREQUEST'].fields_by_name['malloc_volume']._serialized_options = b'\342A\001\002'
  _globals['_CREATEMALLOCVOLUMEREQUEST'].fields_by_name['malloc_volume_id']._options = None
  _globals['_CREATEMALLOCVOLUMEREQUEST'].fields_by_name['malloc_volume_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEMALLOCVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEMALLOCVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.storage.v1/MallocVolume'
  _globals['_DELETEMALLOCVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEMALLOCVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEMALLOCVOLUMEREQUEST'].fields_by_name['malloc_volume']._options = None
  _globals['_UPDATEMALLOCVOLUMEREQUEST'].fields_by_name['malloc_volume']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEMALLOCVOLUMEREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEMALLOCVOLUMEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEMALLOCVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEMALLOCVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTMALLOCVOLUMESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTMALLOCVOLUMESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTMALLOCVOLUMESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTMALLOCVOLUMESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETMALLOCVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETMALLOCVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.storage.v1/MallocVolume'
  _globals['_STATSMALLOCVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSMALLOCVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A!\n\037opi_api.storage.v1/MallocVolume'
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['CreateMallocVolume']._options = None
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['CreateMallocVolume']._serialized_options = b'\332A\036malloc_volume,malloc_volume_id\202\323\344\223\002\"\"\021/v1/mallocVolumes:\rmalloc_volume'
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['DeleteMallocVolume']._options = None
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['DeleteMallocVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\034*\032/v1/{name=mallocVolumes/*}'
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['UpdateMallocVolume']._options = None
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['UpdateMallocVolume']._serialized_options = b'\332A\031malloc_volume,update_mask\202\323\344\223\00292(/v1/{malloc_volume.name=mallocVolumes/*}:\rmalloc_volume'
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['ListMallocVolumes']._options = None
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['ListMallocVolumes']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/mallocVolumes'
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['GetMallocVolume']._options = None
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['GetMallocVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\034\022\032/v1/{name=mallocVolumes/*}'
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['StatsMallocVolume']._options = None
  _globals['_MALLOCVOLUMESERVICE'].methods_by_name['StatsMallocVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\"\022 /v1/{name=mallocVolumes/*}:stats'
  _globals['_MALLOCVOLUME']._serialized_start=240
  _globals['_MALLOCVOLUME']._serialized_end=518
  _globals['_CREATEMALLOCVOLUMEREQUEST']._serialized_start=521
  _globals['_CREATEMALLOCVOLUMEREQUEST']._serialized_end=673
  _globals['_DELETEMALLOCVOLUMEREQUEST']._serialized_start=676
  _globals['_DELETEMALLOCVOLUMEREQUEST']._serialized_end=808
  _globals['_UPDATEMALLOCVOLUMEREQUEST']._serialized_start=811
  _globals['_UPDATEMALLOCVOLUMEREQUEST']._serialized_end=1025
  _globals['_LISTMALLOCVOLUMESREQUEST']._serialized_start=1027
  _globals['_LISTMALLOCVOLUMESREQUEST']._serialized_end=1125
  _globals['_LISTMALLOCVOLUMESRESPONSE']._serialized_start=1128
  _globals['_LISTMALLOCVOLUMESRESPONSE']._serialized_end=1268
  _globals['_GETMALLOCVOLUMEREQUEST']._serialized_start=1270
  _globals['_GETMALLOCVOLUMEREQUEST']._serialized_end=1356
  _globals['_STATSMALLOCVOLUMEREQUEST']._serialized_start=1358
  _globals['_STATSMALLOCVOLUMEREQUEST']._serialized_end=1446
  _globals['_STATSMALLOCVOLUMERESPONSE']._serialized_start=1448
  _globals['_STATSMALLOCVOLUMERESPONSE']._serialized_end=1530
  _globals['_MALLOCVOLUMESERVICE']._serialized_start=1533
  _globals['_MALLOCVOLUMESERVICE']._serialized_end=2514
# @@protoc_insertion_point(module_scope)
