# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: backend_aio.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
import opicommon_pb2 as opicommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x62\x61\x63kend_aio.proto\x12\x12opi_api.storage.v1\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x0fopicommon.proto\"\xfe\x01\n\tAioVolume\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12#\n\nblock_size\x18\x02 \x01(\x03\x42\x04\xe2\x41\x01\x01R\tblockSize\x12\'\n\x0c\x62locks_count\x18\x03 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0b\x62locksCount\x12\x18\n\x04uuid\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01R\x04uuid\x12 \n\x08\x66ilename\x18\x05 \x01(\tB\x04\xe2\x41\x01\x02R\x08\x66ilename:M\xea\x41J\n\x1copi_api.storage.v1/AioVolume\x12\x13\x61ioVolumes/{volume}*\naioVolumes2\taioVolume\"\x86\x01\n\x16\x43reateAioVolumeRequest\x12\x42\n\naio_volume\x18\x01 \x01(\x0b\x32\x1d.opi_api.storage.v1.AioVolumeB\x04\xe2\x41\x01\x02R\taioVolume\x12(\n\raio_volume_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0b\x61ioVolumeId\"~\n\x16\x44\x65leteAioVolumeRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/AioVolumeR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xca\x01\n\x16UpdateAioVolumeRequest\x12\x42\n\naio_volume\x18\x01 \x01(\x0b\x32\x1d.opi_api.storage.v1.AioVolumeB\x04\xe2\x41\x01\x02R\taioVolume\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"_\n\x15ListAioVolumesRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x80\x01\n\x16ListAioVolumesResponse\x12>\n\x0b\x61io_volumes\x18\x01 \x03(\x0b\x32\x1d.opi_api.storage.v1.AioVolumeR\naioVolumes\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"P\n\x13GetAioVolumeRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/AioVolumeR\x04name\"R\n\x15StatsAioVolumeRequest\x12\x39\n\x04name\x18\x01 \x01(\tB%\xe2\x41\x01\x02\xfa\x41\x1e\n\x1copi_api.storage.v1/AioVolumeR\x04name\"O\n\x16StatsAioVolumeResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats2\xf8\x06\n\x10\x41ioVolumeService\x12\x9b\x01\n\x0f\x43reateAioVolume\x12*.opi_api.storage.v1.CreateAioVolumeRequest\x1a\x1d.opi_api.storage.v1.AioVolume\"=\xda\x41\x18\x61io_volume,aio_volume_id\x82\xd3\xe4\x93\x02\x1c\"\x0e/v1/aioVolumes:\naio_volume\x12}\n\x0f\x44\x65leteAioVolume\x12*.opi_api.storage.v1.DeleteAioVolumeRequest\x1a\x16.google.protobuf.Empty\"&\xda\x41\x04name\x82\xd3\xe4\x93\x02\x19*\x17/v1/{name=aioVolumes/*}\x12\xad\x01\n\x0fUpdateAioVolume\x12*.opi_api.storage.v1.UpdateAioVolumeRequest\x1a\x1d.opi_api.storage.v1.AioVolume\"O\xda\x41\x16\x61io_volume,update_mask\x82\xd3\xe4\x93\x02\x30\x32\"/v1/{aio_volume.name=aioVolumes/*}:\naio_volume\x12\x7f\n\x0eListAioVolumes\x12).opi_api.storage.v1.ListAioVolumesRequest\x1a*.opi_api.storage.v1.ListAioVolumesResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/aioVolumes\x12~\n\x0cGetAioVolume\x12\'.opi_api.storage.v1.GetAioVolumeRequest\x1a\x1d.opi_api.storage.v1.AioVolume\"&\xda\x41\x04name\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{name=aioVolumes/*}\x12\x95\x01\n\x0eStatsAioVolume\x12).opi_api.storage.v1.StatsAioVolumeRequest\x1a*.opi_api.storage.v1.StatsAioVolumeResponse\",\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/{name=aioVolumes/*}:statsB^\n\x12opi_api.storage.v1B\x0f\x42\x61\x63kendAioProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'backend_aio_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\017BackendAioProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_AIOVOLUME'].fields_by_name['name']._options = None
  _globals['_AIOVOLUME'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_AIOVOLUME'].fields_by_name['block_size']._options = None
  _globals['_AIOVOLUME'].fields_by_name['block_size']._serialized_options = b'\342A\001\001'
  _globals['_AIOVOLUME'].fields_by_name['blocks_count']._options = None
  _globals['_AIOVOLUME'].fields_by_name['blocks_count']._serialized_options = b'\342A\001\001'
  _globals['_AIOVOLUME'].fields_by_name['uuid']._options = None
  _globals['_AIOVOLUME'].fields_by_name['uuid']._serialized_options = b'\342A\001\001'
  _globals['_AIOVOLUME'].fields_by_name['filename']._options = None
  _globals['_AIOVOLUME'].fields_by_name['filename']._serialized_options = b'\342A\001\002'
  _globals['_AIOVOLUME']._options = None
  _globals['_AIOVOLUME']._serialized_options = b'\352AJ\n\034opi_api.storage.v1/AioVolume\022\023aioVolumes/{volume}*\naioVolumes2\taioVolume'
  _globals['_CREATEAIOVOLUMEREQUEST'].fields_by_name['aio_volume']._options = None
  _globals['_CREATEAIOVOLUMEREQUEST'].fields_by_name['aio_volume']._serialized_options = b'\342A\001\002'
  _globals['_CREATEAIOVOLUMEREQUEST'].fields_by_name['aio_volume_id']._options = None
  _globals['_CREATEAIOVOLUMEREQUEST'].fields_by_name['aio_volume_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEAIOVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEAIOVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.storage.v1/AioVolume'
  _globals['_DELETEAIOVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEAIOVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEAIOVOLUMEREQUEST'].fields_by_name['aio_volume']._options = None
  _globals['_UPDATEAIOVOLUMEREQUEST'].fields_by_name['aio_volume']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEAIOVOLUMEREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEAIOVOLUMEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEAIOVOLUMEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEAIOVOLUMEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTAIOVOLUMESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTAIOVOLUMESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTAIOVOLUMESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTAIOVOLUMESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETAIOVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETAIOVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.storage.v1/AioVolume'
  _globals['_STATSAIOVOLUMEREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSAIOVOLUMEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\036\n\034opi_api.storage.v1/AioVolume'
  _globals['_AIOVOLUMESERVICE'].methods_by_name['CreateAioVolume']._options = None
  _globals['_AIOVOLUMESERVICE'].methods_by_name['CreateAioVolume']._serialized_options = b'\332A\030aio_volume,aio_volume_id\202\323\344\223\002\034\"\016/v1/aioVolumes:\naio_volume'
  _globals['_AIOVOLUMESERVICE'].methods_by_name['DeleteAioVolume']._options = None
  _globals['_AIOVOLUMESERVICE'].methods_by_name['DeleteAioVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\031*\027/v1/{name=aioVolumes/*}'
  _globals['_AIOVOLUMESERVICE'].methods_by_name['UpdateAioVolume']._options = None
  _globals['_AIOVOLUMESERVICE'].methods_by_name['UpdateAioVolume']._serialized_options = b'\332A\026aio_volume,update_mask\202\323\344\223\00202\"/v1/{aio_volume.name=aioVolumes/*}:\naio_volume'
  _globals['_AIOVOLUMESERVICE'].methods_by_name['ListAioVolumes']._options = None
  _globals['_AIOVOLUMESERVICE'].methods_by_name['ListAioVolumes']._serialized_options = b'\202\323\344\223\002\020\022\016/v1/aioVolumes'
  _globals['_AIOVOLUMESERVICE'].methods_by_name['GetAioVolume']._options = None
  _globals['_AIOVOLUMESERVICE'].methods_by_name['GetAioVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\031\022\027/v1/{name=aioVolumes/*}'
  _globals['_AIOVOLUMESERVICE'].methods_by_name['StatsAioVolume']._options = None
  _globals['_AIOVOLUMESERVICE'].methods_by_name['StatsAioVolume']._serialized_options = b'\332A\004name\202\323\344\223\002\037\022\035/v1/{name=aioVolumes/*}:stats'
  _globals['_AIOVOLUME']._serialized_start=237
  _globals['_AIOVOLUME']._serialized_end=491
  _globals['_CREATEAIOVOLUMEREQUEST']._serialized_start=494
  _globals['_CREATEAIOVOLUMEREQUEST']._serialized_end=628
  _globals['_DELETEAIOVOLUMEREQUEST']._serialized_start=630
  _globals['_DELETEAIOVOLUMEREQUEST']._serialized_end=756
  _globals['_UPDATEAIOVOLUMEREQUEST']._serialized_start=759
  _globals['_UPDATEAIOVOLUMEREQUEST']._serialized_end=961
  _globals['_LISTAIOVOLUMESREQUEST']._serialized_start=963
  _globals['_LISTAIOVOLUMESREQUEST']._serialized_end=1058
  _globals['_LISTAIOVOLUMESRESPONSE']._serialized_start=1061
  _globals['_LISTAIOVOLUMESRESPONSE']._serialized_end=1189
  _globals['_GETAIOVOLUMEREQUEST']._serialized_start=1191
  _globals['_GETAIOVOLUMEREQUEST']._serialized_end=1271
  _globals['_STATSAIOVOLUMEREQUEST']._serialized_start=1273
  _globals['_STATSAIOVOLUMEREQUEST']._serialized_end=1355
  _globals['_STATSAIOVOLUMERESPONSE']._serialized_start=1357
  _globals['_STATSAIOVOLUMERESPONSE']._serialized_end=1436
  _globals['_AIOVOLUMESERVICE']._serialized_start=1439
  _globals['_AIOVOLUMESERVICE']._serialized_end=2327
# @@protoc_insertion_point(module_scope)
