# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: backend_nvme.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
import opicommon_pb2 as opicommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x62\x61\x63kend_nvme.proto\x12\x12opi_api.storage.v1\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\x1a\x0fopicommon.proto\"\x84\x03\n\x14NvmeRemoteController\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12\x45\n\tmultipath\x18\x02 \x01(\x0e\x32!.opi_api.storage.v1.NvmeMultipathB\x04\xe2\x41\x01\x02R\tmultipath\x12,\n\x0fio_queues_count\x18\x03 \x01(\x03\x42\x04\xe2\x41\x01\x01R\rioQueuesCount\x12#\n\nqueue_size\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x01R\tqueueSize\x12\x39\n\x03tcp\x18\x05 \x01(\x0b\x32!.opi_api.storage.v1.TcpControllerB\x04\xe2\x41\x01\x01R\x03tcp:}\xea\x41z\n\'opi_api.storage.v1/NvmeRemoteController\x12\"nvmeRemoteControllers/{controller}*\x15nvmeRemoteControllers2\x14nvmeRemoteController\"_\n\rTcpController\x12\x1a\n\x05hdgst\x18\x01 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x05hdgst\x12\x1a\n\x05\x64\x64gst\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x05\x64\x64gst\x12\x16\n\x03psk\x18\x03 \x01(\x0c\x42\x04\xe2\x41\x01\x01R\x03psk\"\xb4\x02\n\x08NvmePath\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12\x43\n\x06trtype\x18\x02 \x01(\x0e\x32%.opi_api.storage.v1.NvmeTransportTypeB\x04\xe2\x41\x01\x02R\x06trtype\x12\x1c\n\x06traddr\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\x06traddr\x12?\n\x07\x66\x61\x62rics\x18\x04 \x01(\x0b\x32\x1f.opi_api.storage.v1.FabricsPathB\x04\xe2\x41\x01\x01R\x07\x66\x61\x62rics:j\xea\x41g\n\x1bopi_api.storage.v1/NvmePath\x12\x33nvmeRemoteControllers/{controller}/nvmePaths/{path}*\tnvmePaths2\x08nvmePath\"\x88\x02\n\x0b\x46\x61\x62ricsPath\x12\x1e\n\x07trsvcid\x18\x01 \x01(\x03\x42\x04\xe2\x41\x01\x02R\x07trsvcid\x12\x1c\n\x06subnqn\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x06subnqn\x12\x43\n\x06\x61\x64rfam\x18\x03 \x01(\x0e\x32%.opi_api.storage.v1.NvmeAddressFamilyB\x04\xe2\x41\x01\x02R\x06\x61\x64rfam\x12)\n\rsource_traddr\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01R\x0csourceTraddr\x12+\n\x0esource_trsvcid\x18\x05 \x01(\x03\x42\x04\xe2\x41\x01\x01R\rsourceTrsvcid\x12\x1e\n\x07hostnqn\x18\x06 \x01(\tB\x04\xe2\x41\x01\x01R\x07hostnqn\"\xba\x02\n\x13NvmeRemoteNamespace\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12\x18\n\x04nsid\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x04nsid\x12\x1a\n\x05nguid\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x05nguid\x12\x1a\n\x05\x65ui64\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x03R\x05\x65ui64\x12\x18\n\x04uuid\x18\x05 \x01(\tB\x04\xe2\x41\x01\x03R\x04uuid:\x9c\x01\xea\x41\x98\x01\n&opi_api.storage.v1/NvmeRemoteNamespace\x12\x43nvmeRemoteControllers/{controller}/nvmeRemoteNamespaces/{namespace}*\x14nvmeRemoteNamespaces2\x13nvmeRemoteNamespace\"\xca\x01\n!CreateNvmeRemoteControllerRequest\x12\x64\n\x16nvme_remote_controller\x18\x01 \x01(\x0b\x32(.opi_api.storage.v1.NvmeRemoteControllerB\x04\xe2\x41\x01\x02R\x14nvmeRemoteController\x12?\n\x19nvme_remote_controller_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x16nvmeRemoteControllerId\"\x94\x01\n!DeleteNvmeRemoteControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/NvmeRemoteControllerR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xf7\x01\n!UpdateNvmeRemoteControllerRequest\x12\x64\n\x16nvme_remote_controller\x18\x01 \x01(\x0b\x32(.opi_api.storage.v1.NvmeRemoteControllerB\x04\xe2\x41\x01\x02R\x14nvmeRemoteController\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"j\n ListNvmeRemoteControllersRequest\x12!\n\tpage_size\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\xad\x01\n!ListNvmeRemoteControllersResponse\x12`\n\x17nvme_remote_controllers\x18\x01 \x03(\x0b\x32(.opi_api.storage.v1.NvmeRemoteControllerR\x15nvmeRemoteControllers\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"f\n\x1eGetNvmeRemoteControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/NvmeRemoteControllerR\x04name\"h\n ResetNvmeRemoteControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/NvmeRemoteControllerR\x04name\"h\n StatsNvmeRemoteControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/NvmeRemoteControllerR\x04name\"Z\n!StatsNvmeRemoteControllerResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats\"\xb2\x01\n\x1fListNvmeRemoteNamespacesRequest\x12G\n\x06parent\x18\x01 \x01(\tB/\xe2\x41\x01\x02\xfa\x41(\x12&opi_api.storage.v1/NvmeRemoteNamespaceR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\xa9\x01\n ListNvmeRemoteNamespacesResponse\x12]\n\x16nvme_remote_namespaces\x18\x01 \x03(\x0b\x32\'.opi_api.storage.v1.NvmeRemoteNamespaceR\x14nvmeRemoteNamespaces\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"d\n\x1dGetNvmeRemoteNamespaceRequest\x12\x43\n\x04name\x18\x01 \x01(\tB/\xe2\x41\x01\x02\xfa\x41(\n&opi_api.storage.v1/NvmeRemoteNamespaceR\x04name\"\xca\x01\n\x15\x43reateNvmePathRequest\x12H\n\x06parent\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/NvmeRemoteControllerR\x06parent\x12?\n\tnvme_path\x18\x02 \x01(\x0b\x32\x1c.opi_api.storage.v1.NvmePathB\x04\xe2\x41\x01\x02R\x08nvmePath\x12&\n\x0cnvme_path_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\nnvmePathId\"|\n\x15\x44\x65leteNvmePathRequest\x12\x38\n\x04name\x18\x01 \x01(\tB$\xe2\x41\x01\x02\xfa\x41\x1d\n\x1bopi_api.storage.v1/NvmePathR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xc6\x01\n\x15UpdateNvmePathRequest\x12?\n\tnvme_path\x18\x01 \x01(\x0b\x32\x1c.opi_api.storage.v1.NvmePathB\x04\xe2\x41\x01\x02R\x08nvmePath\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\x9c\x01\n\x14ListNvmePathsRequest\x12<\n\x06parent\x18\x01 \x01(\tB$\xe2\x41\x01\x02\xfa\x41\x1d\x12\x1bopi_api.storage.v1/NvmePathR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"|\n\x15ListNvmePathsResponse\x12;\n\nnvme_paths\x18\x01 \x03(\x0b\x32\x1c.opi_api.storage.v1.NvmePathR\tnvmePaths\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"N\n\x12GetNvmePathRequest\x12\x38\n\x04name\x18\x01 \x01(\tB$\xe2\x41\x01\x02\xfa\x41\x1d\n\x1bopi_api.storage.v1/NvmePathR\x04name\"P\n\x14StatsNvmePathRequest\x12\x38\n\x04name\x18\x01 \x01(\tB$\xe2\x41\x01\x02\xfa\x41\x1d\n\x1bopi_api.storage.v1/NvmePathR\x04name\"N\n\x15StatsNvmePathResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats*\x86\x01\n\rNvmeMultipath\x12\x1e\n\x1aNVME_MULTIPATH_UNSPECIFIED\x10\x00\x12\x1a\n\x16NVME_MULTIPATH_DISABLE\x10\x01\x12\x1b\n\x17NVME_MULTIPATH_FAILOVER\x10\x02\x12\x1c\n\x18NVME_MULTIPATH_MULTIPATH\x10\x03\x32\x86\x16\n\x1bNvmeRemoteControllerService\x12\xeb\x01\n\x1a\x43reateNvmeRemoteController\x12\x35.opi_api.storage.v1.CreateNvmeRemoteControllerRequest\x1a(.opi_api.storage.v1.NvmeRemoteController\"l\xda\x41\x30nvme_remote_controller,nvme_remote_controller_id\x82\xd3\xe4\x93\x02\x33\"\x19/v1/nvmeRemoteControllers:\x16nvme_remote_controller\x12\x9e\x01\n\x1a\x44\x65leteNvmeRemoteController\x12\x35.opi_api.storage.v1.DeleteNvmeRemoteControllerRequest\x1a\x16.google.protobuf.Empty\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$*\"/v1/{name=nvmeRemoteControllers/*}\x12\xfd\x01\n\x1aUpdateNvmeRemoteController\x12\x35.opi_api.storage.v1.UpdateNvmeRemoteControllerRequest\x1a(.opi_api.storage.v1.NvmeRemoteController\"~\xda\x41\"nvme_remote_controller,update_mask\x82\xd3\xe4\x93\x02S29/v1/{nvme_remote_controller.name=nvmeRemoteControllers/*}:\x16nvme_remote_controller\x12\xab\x01\n\x19ListNvmeRemoteControllers\x12\x34.opi_api.storage.v1.ListNvmeRemoteControllersRequest\x1a\x35.opi_api.storage.v1.ListNvmeRemoteControllersResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/nvmeRemoteControllers\x12\xaa\x01\n\x17GetNvmeRemoteController\x12\x32.opi_api.storage.v1.GetNvmeRemoteControllerRequest\x1a(.opi_api.storage.v1.NvmeRemoteController\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$\x12\"/v1/{name=nvmeRemoteControllers/*}\x12\xa5\x01\n\x19ResetNvmeRemoteController\x12\x34.opi_api.storage.v1.ResetNvmeRemoteControllerRequest\x1a\x16.google.protobuf.Empty\":\xda\x41\x04name\x82\xd3\xe4\x93\x02-\"(/v1/{name=nvmeRemoteControllers/*}:reset:\x01*\x12\xc1\x01\n\x19StatsNvmeRemoteController\x12\x34.opi_api.storage.v1.StatsNvmeRemoteControllerRequest\x1a\x35.opi_api.storage.v1.StatsNvmeRemoteControllerResponse\"7\xda\x41\x04name\x82\xd3\xe4\x93\x02*\x12(/v1/{name=nvmeRemoteControllers/*}:stats\x12\xd1\x01\n\x18ListNvmeRemoteNamespaces\x12\x33.opi_api.storage.v1.ListNvmeRemoteNamespacesRequest\x1a\x34.opi_api.storage.v1.ListNvmeRemoteNamespacesResponse\"J\xda\x41\x06parent\x82\xd3\xe4\x93\x02;\x12\x39/v1/{parent=nvmeRemoteControllers/*}/nvmeRemoteNamespaces\x12\xbe\x01\n\x16GetNvmeRemoteNamespace\x12\x31.opi_api.storage.v1.GetNvmeRemoteNamespaceRequest\x1a\'.opi_api.storage.v1.NvmeRemoteNamespace\"H\xda\x41\x04name\x82\xd3\xe4\x93\x02;\x12\x39/v1/{name=nvmeRemoteControllers/*/nvmeRemoteNamespaces/*}\x12\xbc\x01\n\x0e\x43reateNvmePath\x12).opi_api.storage.v1.CreateNvmePathRequest\x1a\x1c.opi_api.storage.v1.NvmePath\"a\xda\x41\x1dparent,nvme_path,nvme_path_id\x82\xd3\xe4\x93\x02;\"./v1/{parent=nvmeRemoteControllers/*}/nvmePaths:\tnvme_path\x12\x92\x01\n\x0e\x44\x65leteNvmePath\x12).opi_api.storage.v1.DeleteNvmePathRequest\x1a\x16.google.protobuf.Empty\"=\xda\x41\x04name\x82\xd3\xe4\x93\x02\x30*./v1/{name=nvmeRemoteControllers/*/nvmePaths/*}\x12\xbe\x01\n\x0eUpdateNvmePath\x12).opi_api.storage.v1.UpdateNvmePathRequest\x1a\x1c.opi_api.storage.v1.NvmePath\"c\xda\x41\x15nvme_path,update_mask\x82\xd3\xe4\x93\x02\x45\x32\x38/v1/{nvme_path.name=nvmeRemoteControllers/*/nvmePaths/*}:\tnvme_path\x12\xa5\x01\n\rListNvmePaths\x12(.opi_api.storage.v1.ListNvmePathsRequest\x1a).opi_api.storage.v1.ListNvmePathsResponse\"?\xda\x41\x06parent\x82\xd3\xe4\x93\x02\x30\x12./v1/{parent=nvmeRemoteControllers/*}/nvmePaths\x12\x92\x01\n\x0bGetNvmePath\x12&.opi_api.storage.v1.GetNvmePathRequest\x1a\x1c.opi_api.storage.v1.NvmePath\"=\xda\x41\x04name\x82\xd3\xe4\x93\x02\x30\x12./v1/{name=nvmeRemoteControllers/*/nvmePaths/*}\x12\xa9\x01\n\rStatsNvmePath\x12(.opi_api.storage.v1.StatsNvmePathRequest\x1a).opi_api.storage.v1.StatsNvmePathResponse\"C\xda\x41\x04name\x82\xd3\xe4\x93\x02\x36\x12\x34/v1/{name=nvmeRemoteControllers/*/nvmePaths/*}:statsB_\n\x12opi_api.storage.v1B\x10\x42\x61\x63kendNvmeProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'backend_nvme_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\020BackendNvmeProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['name']._options = None
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['multipath']._options = None
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['multipath']._serialized_options = b'\342A\001\002'
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['io_queues_count']._options = None
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['io_queues_count']._serialized_options = b'\342A\001\001'
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['queue_size']._options = None
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['queue_size']._serialized_options = b'\342A\001\001'
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['tcp']._options = None
  _globals['_NVMEREMOTECONTROLLER'].fields_by_name['tcp']._serialized_options = b'\342A\001\001'
  _globals['_NVMEREMOTECONTROLLER']._options = None
  _globals['_NVMEREMOTECONTROLLER']._serialized_options = b'\352Az\n\'opi_api.storage.v1/NvmeRemoteController\022\"nvmeRemoteControllers/{controller}*\025nvmeRemoteControllers2\024nvmeRemoteController'
  _globals['_TCPCONTROLLER'].fields_by_name['hdgst']._options = None
  _globals['_TCPCONTROLLER'].fields_by_name['hdgst']._serialized_options = b'\342A\001\001'
  _globals['_TCPCONTROLLER'].fields_by_name['ddgst']._options = None
  _globals['_TCPCONTROLLER'].fields_by_name['ddgst']._serialized_options = b'\342A\001\001'
  _globals['_TCPCONTROLLER'].fields_by_name['psk']._options = None
  _globals['_TCPCONTROLLER'].fields_by_name['psk']._serialized_options = b'\342A\001\001'
  _globals['_NVMEPATH'].fields_by_name['name']._options = None
  _globals['_NVMEPATH'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NVMEPATH'].fields_by_name['trtype']._options = None
  _globals['_NVMEPATH'].fields_by_name['trtype']._serialized_options = b'\342A\001\002'
  _globals['_NVMEPATH'].fields_by_name['traddr']._options = None
  _globals['_NVMEPATH'].fields_by_name['traddr']._serialized_options = b'\342A\001\002'
  _globals['_NVMEPATH'].fields_by_name['fabrics']._options = None
  _globals['_NVMEPATH'].fields_by_name['fabrics']._serialized_options = b'\342A\001\001'
  _globals['_NVMEPATH']._options = None
  _globals['_NVMEPATH']._serialized_options = b'\352Ag\n\033opi_api.storage.v1/NvmePath\0223nvmeRemoteControllers/{controller}/nvmePaths/{path}*\tnvmePaths2\010nvmePath'
  _globals['_FABRICSPATH'].fields_by_name['trsvcid']._options = None
  _globals['_FABRICSPATH'].fields_by_name['trsvcid']._serialized_options = b'\342A\001\002'
  _globals['_FABRICSPATH'].fields_by_name['subnqn']._options = None
  _globals['_FABRICSPATH'].fields_by_name['subnqn']._serialized_options = b'\342A\001\002'
  _globals['_FABRICSPATH'].fields_by_name['adrfam']._options = None
  _globals['_FABRICSPATH'].fields_by_name['adrfam']._serialized_options = b'\342A\001\002'
  _globals['_FABRICSPATH'].fields_by_name['source_traddr']._options = None
  _globals['_FABRICSPATH'].fields_by_name['source_traddr']._serialized_options = b'\342A\001\001'
  _globals['_FABRICSPATH'].fields_by_name['source_trsvcid']._options = None
  _globals['_FABRICSPATH'].fields_by_name['source_trsvcid']._serialized_options = b'\342A\001\001'
  _globals['_FABRICSPATH'].fields_by_name['hostnqn']._options = None
  _globals['_FABRICSPATH'].fields_by_name['hostnqn']._serialized_options = b'\342A\001\001'
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['name']._options = None
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['nsid']._options = None
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['nsid']._serialized_options = b'\342A\001\003'
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['nguid']._options = None
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['nguid']._serialized_options = b'\342A\001\003'
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['eui64']._options = None
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['eui64']._serialized_options = b'\342A\001\003'
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['uuid']._options = None
  _globals['_NVMEREMOTENAMESPACE'].fields_by_name['uuid']._serialized_options = b'\342A\001\003'
  _globals['_NVMEREMOTENAMESPACE']._options = None
  _globals['_NVMEREMOTENAMESPACE']._serialized_options = b'\352A\230\001\n&opi_api.storage.v1/NvmeRemoteNamespace\022CnvmeRemoteControllers/{controller}/nvmeRemoteNamespaces/{namespace}*\024nvmeRemoteNamespaces2\023nvmeRemoteNamespace'
  _globals['_CREATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['nvme_remote_controller']._options = None
  _globals['_CREATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['nvme_remote_controller']._serialized_options = b'\342A\001\002'
  _globals['_CREATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['nvme_remote_controller_id']._options = None
  _globals['_CREATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['nvme_remote_controller_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETENVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/NvmeRemoteController'
  _globals['_DELETENVMEREMOTECONTROLLERREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETENVMEREMOTECONTROLLERREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['nvme_remote_controller']._options = None
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['nvme_remote_controller']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMEREMOTECONTROLLERSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNVMEREMOTECONTROLLERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMEREMOTECONTROLLERSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNVMEREMOTECONTROLLERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/NvmeRemoteController'
  _globals['_RESETNVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_RESETNVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/NvmeRemoteController'
  _globals['_STATSNVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSNVMEREMOTECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/NvmeRemoteController'
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A(\022&opi_api.storage.v1/NvmeRemoteNamespace'
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNVMEREMOTENAMESPACEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNVMEREMOTENAMESPACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A(\n&opi_api.storage.v1/NvmeRemoteNamespace'
  _globals['_CREATENVMEPATHREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATENVMEPATHREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/NvmeRemoteController'
  _globals['_CREATENVMEPATHREQUEST'].fields_by_name['nvme_path']._options = None
  _globals['_CREATENVMEPATHREQUEST'].fields_by_name['nvme_path']._serialized_options = b'\342A\001\002'
  _globals['_CREATENVMEPATHREQUEST'].fields_by_name['nvme_path_id']._options = None
  _globals['_CREATENVMEPATHREQUEST'].fields_by_name['nvme_path_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETENVMEPATHREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENVMEPATHREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\035\n\033opi_api.storage.v1/NvmePath'
  _globals['_DELETENVMEPATHREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETENVMEPATHREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMEPATHREQUEST'].fields_by_name['nvme_path']._options = None
  _globals['_UPDATENVMEPATHREQUEST'].fields_by_name['nvme_path']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENVMEPATHREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENVMEPATHREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMEPATHREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENVMEPATHREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMEPATHSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTNVMEPATHSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\035\022\033opi_api.storage.v1/NvmePath'
  _globals['_LISTNVMEPATHSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNVMEPATHSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMEPATHSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNVMEPATHSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNVMEPATHREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNVMEPATHREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\035\n\033opi_api.storage.v1/NvmePath'
  _globals['_STATSNVMEPATHREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSNVMEPATHREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\035\n\033opi_api.storage.v1/NvmePath'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['CreateNvmeRemoteController']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['CreateNvmeRemoteController']._serialized_options = b'\332A0nvme_remote_controller,nvme_remote_controller_id\202\323\344\223\0023\"\031/v1/nvmeRemoteControllers:\026nvme_remote_controller'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['DeleteNvmeRemoteController']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['DeleteNvmeRemoteController']._serialized_options = b'\332A\004name\202\323\344\223\002$*\"/v1/{name=nvmeRemoteControllers/*}'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['UpdateNvmeRemoteController']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['UpdateNvmeRemoteController']._serialized_options = b'\332A\"nvme_remote_controller,update_mask\202\323\344\223\002S29/v1/{nvme_remote_controller.name=nvmeRemoteControllers/*}:\026nvme_remote_controller'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ListNvmeRemoteControllers']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ListNvmeRemoteControllers']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/nvmeRemoteControllers'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['GetNvmeRemoteController']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['GetNvmeRemoteController']._serialized_options = b'\332A\004name\202\323\344\223\002$\022\"/v1/{name=nvmeRemoteControllers/*}'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ResetNvmeRemoteController']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ResetNvmeRemoteController']._serialized_options = b'\332A\004name\202\323\344\223\002-\"(/v1/{name=nvmeRemoteControllers/*}:reset:\001*'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['StatsNvmeRemoteController']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['StatsNvmeRemoteController']._serialized_options = b'\332A\004name\202\323\344\223\002*\022(/v1/{name=nvmeRemoteControllers/*}:stats'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ListNvmeRemoteNamespaces']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ListNvmeRemoteNamespaces']._serialized_options = b'\332A\006parent\202\323\344\223\002;\0229/v1/{parent=nvmeRemoteControllers/*}/nvmeRemoteNamespaces'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['GetNvmeRemoteNamespace']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['GetNvmeRemoteNamespace']._serialized_options = b'\332A\004name\202\323\344\223\002;\0229/v1/{name=nvmeRemoteControllers/*/nvmeRemoteNamespaces/*}'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['CreateNvmePath']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['CreateNvmePath']._serialized_options = b'\332A\035parent,nvme_path,nvme_path_id\202\323\344\223\002;\"./v1/{parent=nvmeRemoteControllers/*}/nvmePaths:\tnvme_path'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['DeleteNvmePath']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['DeleteNvmePath']._serialized_options = b'\332A\004name\202\323\344\223\0020*./v1/{name=nvmeRemoteControllers/*/nvmePaths/*}'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['UpdateNvmePath']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['UpdateNvmePath']._serialized_options = b'\332A\025nvme_path,update_mask\202\323\344\223\002E28/v1/{nvme_path.name=nvmeRemoteControllers/*/nvmePaths/*}:\tnvme_path'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ListNvmePaths']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['ListNvmePaths']._serialized_options = b'\332A\006parent\202\323\344\223\0020\022./v1/{parent=nvmeRemoteControllers/*}/nvmePaths'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['GetNvmePath']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['GetNvmePath']._serialized_options = b'\332A\004name\202\323\344\223\0020\022./v1/{name=nvmeRemoteControllers/*/nvmePaths/*}'
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['StatsNvmePath']._options = None
  _globals['_NVMEREMOTECONTROLLERSERVICE'].methods_by_name['StatsNvmePath']._serialized_options = b'\332A\004name\202\323\344\223\0026\0224/v1/{name=nvmeRemoteControllers/*/nvmePaths/*}:stats'
  _globals['_NVMEMULTIPATH']._serialized_start=4433
  _globals['_NVMEMULTIPATH']._serialized_end=4567
  _globals['_NVMEREMOTECONTROLLER']._serialized_start=238
  _globals['_NVMEREMOTECONTROLLER']._serialized_end=626
  _globals['_TCPCONTROLLER']._serialized_start=628
  _globals['_TCPCONTROLLER']._serialized_end=723
  _globals['_NVMEPATH']._serialized_start=726
  _globals['_NVMEPATH']._serialized_end=1034
  _globals['_FABRICSPATH']._serialized_start=1037
  _globals['_FABRICSPATH']._serialized_end=1301
  _globals['_NVMEREMOTENAMESPACE']._serialized_start=1304
  _globals['_NVMEREMOTENAMESPACE']._serialized_end=1618
  _globals['_CREATENVMEREMOTECONTROLLERREQUEST']._serialized_start=1621
  _globals['_CREATENVMEREMOTECONTROLLERREQUEST']._serialized_end=1823
  _globals['_DELETENVMEREMOTECONTROLLERREQUEST']._serialized_start=1826
  _globals['_DELETENVMEREMOTECONTROLLERREQUEST']._serialized_end=1974
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST']._serialized_start=1977
  _globals['_UPDATENVMEREMOTECONTROLLERREQUEST']._serialized_end=2224
  _globals['_LISTNVMEREMOTECONTROLLERSREQUEST']._serialized_start=2226
  _globals['_LISTNVMEREMOTECONTROLLERSREQUEST']._serialized_end=2332
  _globals['_LISTNVMEREMOTECONTROLLERSRESPONSE']._serialized_start=2335
  _globals['_LISTNVMEREMOTECONTROLLERSRESPONSE']._serialized_end=2508
  _globals['_GETNVMEREMOTECONTROLLERREQUEST']._serialized_start=2510
  _globals['_GETNVMEREMOTECONTROLLERREQUEST']._serialized_end=2612
  _globals['_RESETNVMEREMOTECONTROLLERREQUEST']._serialized_start=2614
  _globals['_RESETNVMEREMOTECONTROLLERREQUEST']._serialized_end=2718
  _globals['_STATSNVMEREMOTECONTROLLERREQUEST']._serialized_start=2720
  _globals['_STATSNVMEREMOTECONTROLLERREQUEST']._serialized_end=2824
  _globals['_STATSNVMEREMOTECONTROLLERRESPONSE']._serialized_start=2826
  _globals['_STATSNVMEREMOTECONTROLLERRESPONSE']._serialized_end=2916
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST']._serialized_start=2919
  _globals['_LISTNVMEREMOTENAMESPACESREQUEST']._serialized_end=3097
  _globals['_LISTNVMEREMOTENAMESPACESRESPONSE']._serialized_start=3100
  _globals['_LISTNVMEREMOTENAMESPACESRESPONSE']._serialized_end=3269
  _globals['_GETNVMEREMOTENAMESPACEREQUEST']._serialized_start=3271
  _globals['_GETNVMEREMOTENAMESPACEREQUEST']._serialized_end=3371
  _globals['_CREATENVMEPATHREQUEST']._serialized_start=3374
  _globals['_CREATENVMEPATHREQUEST']._serialized_end=3576
  _globals['_DELETENVMEPATHREQUEST']._serialized_start=3578
  _globals['_DELETENVMEPATHREQUEST']._serialized_end=3702
  _globals['_UPDATENVMEPATHREQUEST']._serialized_start=3705
  _globals['_UPDATENVMEPATHREQUEST']._serialized_end=3903
  _globals['_LISTNVMEPATHSREQUEST']._serialized_start=3906
  _globals['_LISTNVMEPATHSREQUEST']._serialized_end=4062
  _globals['_LISTNVMEPATHSRESPONSE']._serialized_start=4064
  _globals['_LISTNVMEPATHSRESPONSE']._serialized_end=4188
  _globals['_GETNVMEPATHREQUEST']._serialized_start=4190
  _globals['_GETNVMEPATHREQUEST']._serialized_end=4268
  _globals['_STATSNVMEPATHREQUEST']._serialized_start=4270
  _globals['_STATSNVMEPATHREQUEST']._serialized_end=4350
  _globals['_STATSNVMEPATHRESPONSE']._serialized_start=4352
  _globals['_STATSNVMEPATHRESPONSE']._serialized_end=4430
  _globals['_NVMEREMOTECONTROLLERSERVICE']._serialized_start=4570
  _globals['_NVMEREMOTECONTROLLERSERVICE']._serialized_end=7392
# @@protoc_insertion_point(module_scope)
