# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: component.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63omponent.proto\x12 opi_api.network.evpn_gw.v1alpha1\x1a\x1fgoogle/api/field_behavior.proto\"\x91\x01\n\tComponent\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04name\x12J\n\x06status\x18\x02 \x01(\x0e\x32,.opi_api.network.evpn_gw.v1alpha1.CompStatusB\x04\xe2\x41\x01\x03R\x06status\x12\x1e\n\x07\x64\x65tails\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x07\x64\x65tails*r\n\nCompStatus\x12\x1b\n\x17\x43OMP_STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13\x43OMP_STATUS_PENDING\x10\x01\x12\x17\n\x13\x43OMP_STATUS_SUCCESS\x10\x02\x12\x15\n\x11\x43OMP_STATUS_ERROR\x10\x03\x42s\n opi_api.network.evpn_gw.v1alpha1B\x0e\x43omponentProtoP\x01Z=github.com/opiproject/opi-api/network/evpn-gw/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'component_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n opi_api.network.evpn_gw.v1alpha1B\016ComponentProtoP\001Z=github.com/opiproject/opi-api/network/evpn-gw/v1alpha1/gen/go'
  _globals['_COMPONENT'].fields_by_name['name']._options = None
  _globals['_COMPONENT'].fields_by_name['name']._serialized_options = b'\342A\001\003'
  _globals['_COMPONENT'].fields_by_name['status']._options = None
  _globals['_COMPONENT'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_COMPONENT'].fields_by_name['details']._options = None
  _globals['_COMPONENT'].fields_by_name['details']._serialized_options = b'\342A\001\003'
  _globals['_COMPSTATUS']._serialized_start=234
  _globals['_COMPSTATUS']._serialized_end=348
  _globals['_COMPONENT']._serialized_start=87
  _globals['_COMPONENT']._serialized_end=232
# @@protoc_insertion_point(module_scope)
