# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opicommon.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fopicommon.proto\x12\x12opi_api.storage.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xe7\x01\n\x0bPciEndpoint\x12:\n\x07port_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x04\xe2\x41\x01\x02R\x06portId\x12N\n\x11physical_function\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x04\xe2\x41\x01\x02R\x10physicalFunction\x12L\n\x10virtual_function\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueB\x04\xe2\x41\x01\x02R\x0fvirtualFunction\"\x94\x01\n\x0f\x46\x61\x62ricsEndpoint\x12\x1c\n\x06traddr\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x06traddr\x12\x1e\n\x07trsvcid\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\x07trsvcid\x12\x43\n\x06\x61\x64rfam\x18\x03 \x01(\x0e\x32%.opi_api.storage.v1.NvmeAddressFamilyB\x04\xe2\x41\x01\x02R\x06\x61\x64rfam\"\xc9\x03\n\x0bVolumeStats\x12.\n\x10read_bytes_count\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x0ereadBytesCount\x12*\n\x0eread_ops_count\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x0creadOpsCount\x12\x30\n\x11write_bytes_count\x18\x03 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x0fwriteBytesCount\x12,\n\x0fwrite_ops_count\x18\x04 \x01(\x05\x42\x04\xe2\x41\x01\x03R\rwriteOpsCount\x12\x30\n\x11unmap_bytes_count\x18\x05 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x0funmapBytesCount\x12,\n\x0funmap_ops_count\x18\x06 \x01(\x05\x42\x04\xe2\x41\x01\x03R\runmapOpsCount\x12\x32\n\x12read_latency_ticks\x18\x07 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x10readLatencyTicks\x12\x34\n\x13write_latency_ticks\x18\x08 \x01(\x05\x42\x04\xe2\x41\x01\x03R\x11writeLatencyTicks\x12\x34\n\x13unmap_latency_ticks\x18\t \x01(\x05\x42\x04\xe2\x41\x01\x03R\x11unmapLatencyTicks\"\x98\x02\n\x08QosLimit\x12(\n\rrd_iops_kiops\x18\x01 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0brdIopsKiops\x12(\n\rwr_iops_kiops\x18\x02 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0bwrIopsKiops\x12(\n\rrw_iops_kiops\x18\x03 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0brwIopsKiops\x12.\n\x10rd_bandwidth_mbs\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0erdBandwidthMbs\x12.\n\x10wr_bandwidth_mbs\x18\x05 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0ewrBandwidthMbs\x12.\n\x10rw_bandwidth_mbs\x18\x06 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x0erwBandwidthMbs*\xf7\x01\n\x0e\x45ncryptionType\x12\x1f\n\x1b\x45NCRYPTION_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_CBC_128\x10\x01\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_CBC_192\x10\x02\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_CBC_256\x10\x03\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_XTS_128\x10\x04\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_XTS_192\x10\x05\x12\x1f\n\x1b\x45NCRYPTION_TYPE_AES_XTS_256\x10\x06*\xcd\x01\n\x11NvmeTransportType\x12#\n\x1fNVME_TRANSPORT_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16NVME_TRANSPORT_TYPE_FC\x10\x01\x12\x1c\n\x18NVME_TRANSPORT_TYPE_PCIE\x10\x02\x12\x1c\n\x18NVME_TRANSPORT_TYPE_RDMA\x10\x03\x12\x1b\n\x17NVME_TRANSPORT_TYPE_TCP\x10\x04\x12\x1e\n\x1aNVME_TRANSPORT_TYPE_CUSTOM\x10\x05*\xd0\x01\n\x11NvmeAddressFamily\x12#\n\x1fNVME_ADDRESS_FAMILY_UNSPECIFIED\x10\x00\x12\x1c\n\x18NVME_ADDRESS_FAMILY_IPV4\x10\x01\x12\x1c\n\x18NVME_ADDRESS_FAMILY_IPV6\x10\x02\x12\x1a\n\x16NVME_ADDRESS_FAMILY_IB\x10\x03\x12\x1a\n\x16NVME_ADDRESS_FAMILY_FC\x10\x04\x12\"\n\x1eNVME_ADDRESS_FAMILY_INTRA_HOST\x10\x05\x42]\n\x12opi_api.storage.v1B\x0eOpiCommonProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opicommon_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\016OpiCommonProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_PCIENDPOINT'].fields_by_name['port_id']._options = None
  _globals['_PCIENDPOINT'].fields_by_name['port_id']._serialized_options = b'\342A\001\002'
  _globals['_PCIENDPOINT'].fields_by_name['physical_function']._options = None
  _globals['_PCIENDPOINT'].fields_by_name['physical_function']._serialized_options = b'\342A\001\002'
  _globals['_PCIENDPOINT'].fields_by_name['virtual_function']._options = None
  _globals['_PCIENDPOINT'].fields_by_name['virtual_function']._serialized_options = b'\342A\001\002'
  _globals['_FABRICSENDPOINT'].fields_by_name['traddr']._options = None
  _globals['_FABRICSENDPOINT'].fields_by_name['traddr']._serialized_options = b'\342A\001\002'
  _globals['_FABRICSENDPOINT'].fields_by_name['trsvcid']._options = None
  _globals['_FABRICSENDPOINT'].fields_by_name['trsvcid']._serialized_options = b'\342A\001\002'
  _globals['_FABRICSENDPOINT'].fields_by_name['adrfam']._options = None
  _globals['_FABRICSENDPOINT'].fields_by_name['adrfam']._serialized_options = b'\342A\001\002'
  _globals['_VOLUMESTATS'].fields_by_name['read_bytes_count']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['read_bytes_count']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['read_ops_count']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['read_ops_count']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['write_bytes_count']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['write_bytes_count']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['write_ops_count']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['write_ops_count']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['unmap_bytes_count']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['unmap_bytes_count']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['unmap_ops_count']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['unmap_ops_count']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['read_latency_ticks']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['read_latency_ticks']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['write_latency_ticks']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['write_latency_ticks']._serialized_options = b'\342A\001\003'
  _globals['_VOLUMESTATS'].fields_by_name['unmap_latency_ticks']._options = None
  _globals['_VOLUMESTATS'].fields_by_name['unmap_latency_ticks']._serialized_options = b'\342A\001\003'
  _globals['_QOSLIMIT'].fields_by_name['rd_iops_kiops']._options = None
  _globals['_QOSLIMIT'].fields_by_name['rd_iops_kiops']._serialized_options = b'\342A\001\001'
  _globals['_QOSLIMIT'].fields_by_name['wr_iops_kiops']._options = None
  _globals['_QOSLIMIT'].fields_by_name['wr_iops_kiops']._serialized_options = b'\342A\001\001'
  _globals['_QOSLIMIT'].fields_by_name['rw_iops_kiops']._options = None
  _globals['_QOSLIMIT'].fields_by_name['rw_iops_kiops']._serialized_options = b'\342A\001\001'
  _globals['_QOSLIMIT'].fields_by_name['rd_bandwidth_mbs']._options = None
  _globals['_QOSLIMIT'].fields_by_name['rd_bandwidth_mbs']._serialized_options = b'\342A\001\001'
  _globals['_QOSLIMIT'].fields_by_name['wr_bandwidth_mbs']._options = None
  _globals['_QOSLIMIT'].fields_by_name['wr_bandwidth_mbs']._serialized_options = b'\342A\001\001'
  _globals['_QOSLIMIT'].fields_by_name['rw_bandwidth_mbs']._options = None
  _globals['_QOSLIMIT'].fields_by_name['rw_bandwidth_mbs']._serialized_options = b'\342A\001\001'
  _globals['_ENCRYPTIONTYPE']._serialized_start=1233
  _globals['_ENCRYPTIONTYPE']._serialized_end=1480
  _globals['_NVMETRANSPORTTYPE']._serialized_start=1483
  _globals['_NVMETRANSPORTTYPE']._serialized_end=1688
  _globals['_NVMEADDRESSFAMILY']._serialized_start=1691
  _globals['_NVMEADDRESSFAMILY']._serialized_end=1899
  _globals['_PCIENDPOINT']._serialized_start=105
  _globals['_PCIENDPOINT']._serialized_end=336
  _globals['_FABRICSENDPOINT']._serialized_start=339
  _globals['_FABRICSENDPOINT']._serialized_end=487
  _globals['_VOLUMESTATS']._serialized_start=490
  _globals['_VOLUMESTATS']._serialized_end=947
  _globals['_QOSLIMIT']._serialized_start=950
  _globals['_QOSLIMIT']._serialized_end=1230
# @@protoc_insertion_point(module_scope)
