# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vnic.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nvnic.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\xd3\x01\n\x04Vnic\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12<\n\x04spec\x18\x02 \x01(\x0b\x32(.opi_api.network.cloud.v1alpha1.VnicSpecR\x04spec\x12\x42\n\x06status\x18\x03 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.VnicStatusR\x06status:5\xea\x41\x32\n#opi_api.network.cloud.v1alpha1/vnic\x12\x0bvnic/{vnic}\"\x9b\n\n\x08VnicSpec\x12&\n\x0fsubnet_name_ref\x18\x01 \x01(\tR\rsubnetNameRef\x12K\n\nvnic_encap\x18\x02 \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.EncapR\tvnicEncap\x12\x1f\n\x0bmac_address\x18\x03 \x01(\x0cR\nmacAddress\x12.\n\x13source_guard_enable\x18\x04 \x01(\x08R\x11sourceGuardEnable\x12O\n\x0c\x66\x61\x62ric_encap\x18\x05 \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.EncapR\x0b\x66\x61\x62ricEncap\x12\x10\n\x03vnf\x18\x06 \x01(\x08R\x03vnf\x12K\n#ingress_v4_security_policy_name_ref\x18\x07 \x03(\tR\x1eingressV4SecurityPolicyNameRef\x12K\n#ingress_v6_security_policy_name_ref\x18\x08 \x03(\tR\x1eingressV6SecurityPolicyNameRef\x12I\n\"egress_v4_security_policy_name_ref\x18\t \x03(\tR\x1d\x65gressV4SecurityPolicyNameRef\x12I\n\"egress_v6_security_policy_name_ref\x18\n \x03(\tR\x1d\x65gressV6SecurityPolicyNameRef\x12)\n\x10host_if_name_ref\x18\x0b \x01(\tH\x00R\rhostIfNameRef\x12(\n\x0ftunnel_name_ref\x18\x0c \x01(\tH\x00R\rtunnelNameRef\x12!\n\x0cmax_sessions\x18\r \x01(\x05R\x0bmaxSessions\x12,\n\x12public_mac_address\x18\x0e \x01(\x0cR\x10publicMacAddress\x12\x32\n\x15\x61llow_internet_access\x18\x0f \x01(\x08R\x13\x61llowInternetAccess\x12\x17\n\x07max_cps\x18\x10 \x01(\x05R\x06maxCps\x12\x1b\n\tcps_burst\x18\x11 \x01(\x05R\x08\x63psBurst\x12\x31\n\x15primary_vnic_name_ref\x18\x12 \x01(\tR\x12primaryVnicNameRef\x12\x34\n\x17v4_route_table_name_ref\x18\x13 \x01(\tR\x13v4RouteTableNameRef\x12\x34\n\x17v6_route_table_name_ref\x18\x14 \x01(\tR\x13v6RouteTableNameRef\x12O\n\nservice_ip\x18\x15 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\tserviceIp\x12(\n\x10max_tcp_sessions\x18\x16 \x01(\x05R\x0emaxTcpSessions\x12(\n\x10max_udp_sessions\x18\x17 \x01(\x05R\x0emaxUdpSessions\x12*\n\x11max_icmp_sessions\x18\x18 \x01(\x05R\x0fmaxIcmpSessions\x12,\n\x12max_other_sessions\x18\x19 \x01(\x05R\x10maxOtherSessionsB\x08\n\x06ifinfo\"\xc8\x03\n\nVnicStatus\x12\x31\n\x15max_session_limit_hit\x18\r \x01(\x08R\x12maxSessionLimitHit\x12\x38\n\x19max_tcp_session_limit_hit\x18\x0e \x01(\x08R\x15maxTcpSessionLimitHit\x12\x38\n\x19max_udp_session_limit_hit\x18\x0f \x01(\x08R\x15maxUdpSessionLimitHit\x12:\n\x1amax_icmp_session_limit_hit\x18\x10 \x01(\x08R\x16maxIcmpSessionLimitHit\x12<\n\x1bmax_other_session_limit_hit\x18\x11 \x01(\x08R\x17maxOtherSessionLimitHit\x12\x15\n\x06hw_idx\x18\x01 \x01(\x05R\x05hwIdx\x12$\n\x0enexthop_hw_idx\x18\x02 \x01(\x05R\x0cnexthopHwIdx\x12%\n\x0f\x63ps_copp_hw_idx\x18\n \x01(\x05R\x0c\x63psCoppHwIdx\x12\x35\n\x17secondary_vnic_name_ref\x18\x0b \x01(\tR\x14secondaryVnicNameRefBj\n\x1eopi_api.network.cloud.v1alpha1B\tVnicProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vnic_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\tVnicProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_VNIC']._options = None
  _globals['_VNIC']._serialized_options = b'\352A2\n#opi_api.network.cloud.v1alpha1/vnic\022\013vnic/{vnic}'
  _globals['_VNIC']._serialized_start=94
  _globals['_VNIC']._serialized_end=305
  _globals['_VNICSPEC']._serialized_start=308
  _globals['_VNICSPEC']._serialized_end=1615
  _globals['_VNICSTATUS']._serialized_start=1618
  _globals['_VNICSTATUS']._serialized_end=2074
# @@protoc_insertion_point(module_scope)
