# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: frontend_nvme.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opicommon_pb2 as opicommon__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x66rontend_nvme.proto\x12\x12opi_api.storage.v1\x1a\x0fopicommon.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\x93\x02\n\rNvmeSubsystem\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12?\n\x04spec\x18\x02 \x01(\x0b\x32%.opi_api.storage.v1.NvmeSubsystemSpecB\x04\xe2\x41\x01\x02R\x04spec\x12\x45\n\x06status\x18\x03 \x01(\x0b\x32\'.opi_api.storage.v1.NvmeSubsystemStatusB\x04\xe2\x41\x01\x03R\x06status:`\xea\x41]\n opi_api.storage.v1/NvmeSubsystem\x12\x1anvmeSubsystems/{subsystem}*\x0envmeSubsystems2\rnvmeSubsystem\"\xe4\x01\n\x11NvmeSubsystemSpec\x12\x16\n\x03nqn\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x03nqn\x12)\n\rserial_number\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0cserialNumber\x12\'\n\x0cmodel_number\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\x0bmodelNumber\x12+\n\x0emax_namespaces\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x01R\rmaxNamespaces\x12\x1e\n\x07hostnqn\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01R\x07hostnqn\x12\x16\n\x03psk\x18\x06 \x01(\x0c\x42\x04\xe2\x41\x01\x01R\x03psk\"i\n\x13NvmeSubsystemStatus\x12\x31\n\x11\x66irmware_revision\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x10\x66irmwareRevision\x12\x1f\n\x08\x66ru_guid\x18\x02 \x01(\x0c\x42\x04\xe2\x41\x01\x03R\x07\x66ruGuid\"\xb7\x02\n\x0eNvmeController\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12@\n\x04spec\x18\x02 \x01(\x0b\x32&.opi_api.storage.v1.NvmeControllerSpecB\x04\xe2\x41\x01\x02R\x04spec\x12\x46\n\x06status\x18\x03 \x01(\x0b\x32(.opi_api.storage.v1.NvmeControllerStatusB\x04\xe2\x41\x01\x03R\x06status:\x80\x01\xea\x41}\n!opi_api.storage.v1/NvmeController\x12\x37nvmeSubsystems/{subsystem}/nvmeControllers/{controller}*\x0fnvmeControllers2\x0envmeController\"\xe4\x04\n\x12NvmeControllerSpec\x12\x37\n\x12nvme_controller_id\x18\x01 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x01R\x10nvmeControllerId\x88\x01\x01\x12\x43\n\x06trtype\x18\x02 \x01(\x0e\x32%.opi_api.storage.v1.NvmeTransportTypeB\x04\xe2\x41\x01\x02R\x06trtype\x12@\n\x07pcie_id\x18\x03 \x01(\x0b\x32\x1f.opi_api.storage.v1.PciEndpointB\x04\xe2\x41\x01\x01H\x00R\x06pcieId\x12J\n\nfabrics_id\x18\x04 \x01(\x0b\x32#.opi_api.storage.v1.FabricsEndpointB\x04\xe2\x41\x01\x01H\x00R\tfabricsId\x12\x1d\n\x07max_nsq\x18\x05 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x06maxNsq\x12\x1d\n\x07max_ncq\x18\x06 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x06maxNcq\x12\x18\n\x04sqes\x18\x07 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x04sqes\x12\x18\n\x04\x63qes\x18\x08 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x04\x63qes\x12+\n\x0emax_namespaces\x18\t \x01(\x05\x42\x04\xe2\x41\x01\x01R\rmaxNamespaces\x12?\n\tmin_limit\x18\n \x01(\x0b\x32\x1c.opi_api.storage.v1.QosLimitB\x04\xe2\x41\x01\x01R\x08minLimit\x12?\n\tmax_limit\x18\x0b \x01(\x0b\x32\x1c.opi_api.storage.v1.QosLimitB\x04\xe2\x41\x01\x01R\x08maxLimitB\n\n\x08\x65ndpointB\x15\n\x13_nvme_controller_id\"4\n\x14NvmeControllerStatus\x12\x1c\n\x06\x61\x63tive\x18\x01 \x01(\x08\x42\x04\xe2\x41\x01\x03R\x06\x61\x63tive\"\xae\x02\n\rNvmeNamespace\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12?\n\x04spec\x18\x02 \x01(\x0b\x32%.opi_api.storage.v1.NvmeNamespaceSpecB\x04\xe2\x41\x01\x02R\x04spec\x12\x45\n\x06status\x18\x03 \x01(\x0b\x32\'.opi_api.storage.v1.NvmeNamespaceStatusB\x04\xe2\x41\x01\x03R\x06status:{\xea\x41x\n opi_api.storage.v1/NvmeNamespace\x12\x35nvmeSubsystems/{subsystem}/nvmeNamespaces/{namespace}*\x0envmeNamespaces2\rnvmeNamespace\"\xb6\x01\n\x11NvmeNamespaceSpec\x12!\n\thost_nsid\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08hostNsid\x12\x1a\n\x05nguid\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\x05nguid\x12\x1a\n\x05\x65ui64\x18\x04 \x01(\x03\x42\x04\xe2\x41\x01\x01R\x05\x65ui64\x12\x18\n\x04uuid\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01R\x04uuid\x12,\n\x0fvolume_name_ref\x18\x06 \x01(\tB\x04\xe2\x41\x01\x02R\rvolumeNameRef\"\xeb\x02\n\x13NvmeNamespaceStatus\x12I\n\x05state\x18\x01 \x01(\x0e\x32-.opi_api.storage.v1.NvmeNamespaceStatus.StateB\x04\xe2\x41\x01\x03R\x05state\x12V\n\noper_state\x18\x02 \x01(\x0e\x32\x31.opi_api.storage.v1.NvmeNamespaceStatus.OperStateB\x04\xe2\x41\x01\x03R\toperState\"Y\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTATE_DISABLED\x10\x01\x12\x11\n\rSTATE_ENABLED\x10\x02\x12\x12\n\x0eSTATE_DELETING\x10\x03\"V\n\tOperState\x12\x1a\n\x16OPER_STATE_UNSPECIFIED\x10\x00\x12\x15\n\x11OPER_STATE_ONLINE\x10\x01\x12\x16\n\x12OPER_STATE_OFFLINE\x10\x02\"\x9e\x01\n\x1a\x43reateNvmeSubsystemRequest\x12N\n\x0envme_subsystem\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.NvmeSubsystemB\x04\xe2\x41\x01\x02R\rnvmeSubsystem\x12\x30\n\x11nvme_subsystem_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0fnvmeSubsystemId\"\x86\x01\n\x1a\x44\x65leteNvmeSubsystemRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeSubsystemR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xda\x01\n\x1aUpdateNvmeSubsystemRequest\x12N\n\x0envme_subsystem\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.NvmeSubsystemB\x04\xe2\x41\x01\x02R\rnvmeSubsystem\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"c\n\x19ListNvmeSubsystemsRequest\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x90\x01\n\x1aListNvmeSubsystemsResponse\x12J\n\x0fnvme_subsystems\x18\x01 \x03(\x0b\x32!.opi_api.storage.v1.NvmeSubsystemR\x0envmeSubsystems\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"X\n\x17GetNvmeSubsystemRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeSubsystemR\x04name\"Z\n\x19StatsNvmeSubsystemRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeSubsystemR\x04name\"S\n\x1aStatsNvmeSubsystemResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats\"\xe7\x01\n\x1b\x43reateNvmeControllerRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeSubsystemR\x06parent\x12Q\n\x0fnvme_controller\x18\x02 \x01(\x0b\x32\".opi_api.storage.v1.NvmeControllerB\x04\xe2\x41\x01\x02R\x0envmeController\x12\x32\n\x12nvme_controller_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\x10nvmeControllerId\"\x88\x01\n\x1b\x44\x65leteNvmeControllerRequest\x12>\n\x04name\x18\x01 \x01(\tB*\xe2\x41\x01\x02\xfa\x41#\n!opi_api.storage.v1/NvmeControllerR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xde\x01\n\x1bUpdateNvmeControllerRequest\x12Q\n\x0fnvme_controller\x18\x01 \x01(\x0b\x32\".opi_api.storage.v1.NvmeControllerB\x04\xe2\x41\x01\x02R\x0envmeController\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xa8\x01\n\x1aListNvmeControllersRequest\x12\x42\n\x06parent\x18\x01 \x01(\tB*\xe2\x41\x01\x02\xfa\x41#\x12!opi_api.storage.v1/NvmeControllerR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x94\x01\n\x1bListNvmeControllersResponse\x12M\n\x10nvme_controllers\x18\x01 \x03(\x0b\x32\".opi_api.storage.v1.NvmeControllerR\x0fnvmeControllers\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"Z\n\x18GetNvmeControllerRequest\x12>\n\x04name\x18\x01 \x01(\tB*\xe2\x41\x01\x02\xfa\x41#\n!opi_api.storage.v1/NvmeControllerR\x04name\"\\\n\x1aStatsNvmeControllerRequest\x12>\n\x04name\x18\x01 \x01(\tB*\xe2\x41\x01\x02\xfa\x41#\n!opi_api.storage.v1/NvmeControllerR\x04name\"T\n\x1bStatsNvmeControllerResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats\"\xe1\x01\n\x1a\x43reateNvmeNamespaceRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeSubsystemR\x06parent\x12N\n\x0envme_namespace\x18\x02 \x01(\x0b\x32!.opi_api.storage.v1.NvmeNamespaceB\x04\xe2\x41\x01\x02R\rnvmeNamespace\x12\x30\n\x11nvme_namespace_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\x0fnvmeNamespaceId\"\x86\x01\n\x1a\x44\x65leteNvmeNamespaceRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeNamespaceR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xda\x01\n\x1aUpdateNvmeNamespaceRequest\x12N\n\x0envme_namespace\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.NvmeNamespaceB\x04\xe2\x41\x01\x02R\rnvmeNamespace\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xa6\x01\n\x19ListNvmeNamespacesRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\x12 opi_api.storage.v1/NvmeNamespaceR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x90\x01\n\x1aListNvmeNamespacesResponse\x12J\n\x0fnvme_namespaces\x18\x01 \x03(\x0b\x32!.opi_api.storage.v1.NvmeNamespaceR\x0envmeNamespaces\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"X\n\x17GetNvmeNamespaceRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeNamespaceR\x04name\"Z\n\x19StatsNvmeNamespaceRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/NvmeNamespaceR\x04name\"S\n\x1aStatsNvmeNamespaceResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats2\xd9\x19\n\x13\x46rontendNvmeService\x12\xb7\x01\n\x13\x43reateNvmeSubsystem\x12..opi_api.storage.v1.CreateNvmeSubsystemRequest\x1a!.opi_api.storage.v1.NvmeSubsystem\"M\xda\x41 nvme_subsystem,nvme_subsystem_id\x82\xd3\xe4\x93\x02$\"\x12/v1/nvmeSubsystems:\x0envme_subsystem\x12\x89\x01\n\x13\x44\x65leteNvmeSubsystem\x12..opi_api.storage.v1.DeleteNvmeSubsystemRequest\x1a\x16.google.protobuf.Empty\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/{name=nvmeSubsystems/*}\x12\xc9\x01\n\x13UpdateNvmeSubsystem\x12..opi_api.storage.v1.UpdateNvmeSubsystemRequest\x1a!.opi_api.storage.v1.NvmeSubsystem\"_\xda\x41\x1anvme_subsystem,update_mask\x82\xd3\xe4\x93\x02<2*/v1/{nvme_subsystem.name=nvmeSubsystems/*}:\x0envme_subsystem\x12\x8f\x01\n\x12ListNvmeSubsystems\x12-.opi_api.storage.v1.ListNvmeSubsystemsRequest\x1a..opi_api.storage.v1.ListNvmeSubsystemsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/nvmeSubsystems\x12\x8e\x01\n\x10GetNvmeSubsystem\x12+.opi_api.storage.v1.GetNvmeSubsystemRequest\x1a!.opi_api.storage.v1.NvmeSubsystem\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/{name=nvmeSubsystems/*}\x12\xa5\x01\n\x12StatsNvmeSubsystem\x12-.opi_api.storage.v1.StatsNvmeSubsystemRequest\x1a..opi_api.storage.v1.StatsNvmeSubsystemResponse\"0\xda\x41\x04name\x82\xd3\xe4\x93\x02#\x12!/v1/{name=nvmeSubsystems/*}:stats\x12\xdf\x01\n\x14\x43reateNvmeController\x12/.opi_api.storage.v1.CreateNvmeControllerRequest\x1a\".opi_api.storage.v1.NvmeController\"r\xda\x41)parent,nvme_controller,nvme_controller_id\x82\xd3\xe4\x93\x02@\"-/v1/{parent=nvmeSubsystems/*}/nvmeControllers:\x0fnvme_controller\x12\x9d\x01\n\x14\x44\x65leteNvmeController\x12/.opi_api.storage.v1.DeleteNvmeControllerRequest\x1a\x16.google.protobuf.Empty\"<\xda\x41\x04name\x82\xd3\xe4\x93\x02/*-/v1/{name=nvmeSubsystems/*/nvmeControllers/*}\x12\xe1\x01\n\x14UpdateNvmeController\x12/.opi_api.storage.v1.UpdateNvmeControllerRequest\x1a\".opi_api.storage.v1.NvmeController\"t\xda\x41\x1bnvme_controller,update_mask\x82\xd3\xe4\x93\x02P2=/v1/{nvme_controller.name=nvmeSubsystems/*/nvmeControllers/*}:\x0fnvme_controller\x12\xb6\x01\n\x13ListNvmeControllers\x12..opi_api.storage.v1.ListNvmeControllersRequest\x1a/.opi_api.storage.v1.ListNvmeControllersResponse\">\xda\x41\x06parent\x82\xd3\xe4\x93\x02/\x12-/v1/{parent=nvmeSubsystems/*}/nvmeControllers\x12\xa3\x01\n\x11GetNvmeController\x12,.opi_api.storage.v1.GetNvmeControllerRequest\x1a\".opi_api.storage.v1.NvmeController\"<\xda\x41\x04name\x82\xd3\xe4\x93\x02/\x12-/v1/{name=nvmeSubsystems/*/nvmeControllers/*}\x12\xba\x01\n\x13StatsNvmeController\x12..opi_api.storage.v1.StatsNvmeControllerRequest\x1a/.opi_api.storage.v1.StatsNvmeControllerResponse\"B\xda\x41\x04name\x82\xd3\xe4\x93\x02\x35\x12\x33/v1/{name=nvmeSubsystems/*/nvmeControllers/*}:stats\x12\xd8\x01\n\x13\x43reateNvmeNamespace\x12..opi_api.storage.v1.CreateNvmeNamespaceRequest\x1a!.opi_api.storage.v1.NvmeNamespace\"n\xda\x41\'parent,nvme_namespace,nvme_namespace_id\x82\xd3\xe4\x93\x02>\",/v1/{parent=nvmeSubsystems/*}/nvmeNamespaces:\x0envme_namespace\x12\x9a\x01\n\x13\x44\x65leteNvmeNamespace\x12..opi_api.storage.v1.DeleteNvmeNamespaceRequest\x1a\x16.google.protobuf.Empty\";\xda\x41\x04name\x82\xd3\xe4\x93\x02.*,/v1/{name=nvmeSubsystems/*/nvmeNamespaces/*}\x12\xda\x01\n\x13UpdateNvmeNamespace\x12..opi_api.storage.v1.UpdateNvmeNamespaceRequest\x1a!.opi_api.storage.v1.NvmeNamespace\"p\xda\x41\x1anvme_namespace,update_mask\x82\xd3\xe4\x93\x02M2;/v1/{nvme_namespace.name=nvmeSubsystems/*/nvmeNamespaces/*}:\x0envme_namespace\x12\xb2\x01\n\x12ListNvmeNamespaces\x12-.opi_api.storage.v1.ListNvmeNamespacesRequest\x1a..opi_api.storage.v1.ListNvmeNamespacesResponse\"=\xda\x41\x06parent\x82\xd3\xe4\x93\x02.\x12,/v1/{parent=nvmeSubsystems/*}/nvmeNamespaces\x12\x9f\x01\n\x10GetNvmeNamespace\x12+.opi_api.storage.v1.GetNvmeNamespaceRequest\x1a!.opi_api.storage.v1.NvmeNamespace\";\xda\x41\x04name\x82\xd3\xe4\x93\x02.\x12,/v1/{name=nvmeSubsystems/*/nvmeNamespaces/*}\x12\xb6\x01\n\x12StatsNvmeNamespace\x12-.opi_api.storage.v1.StatsNvmeNamespaceRequest\x1a..opi_api.storage.v1.StatsNvmeNamespaceResponse\"A\xda\x41\x04name\x82\xd3\xe4\x93\x02\x34\x12\x32/v1/{name=nvmeSubsystems/*/nvmeNamespaces/*}:statsB`\n\x12opi_api.storage.v1B\x11\x46rontendNvmeProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'frontend_nvme_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\021FrontendNvmeProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_NVMESUBSYSTEM'].fields_by_name['name']._options = None
  _globals['_NVMESUBSYSTEM'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NVMESUBSYSTEM'].fields_by_name['spec']._options = None
  _globals['_NVMESUBSYSTEM'].fields_by_name['spec']._serialized_options = b'\342A\001\002'
  _globals['_NVMESUBSYSTEM'].fields_by_name['status']._options = None
  _globals['_NVMESUBSYSTEM'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_NVMESUBSYSTEM']._options = None
  _globals['_NVMESUBSYSTEM']._serialized_options = b'\352A]\n opi_api.storage.v1/NvmeSubsystem\022\032nvmeSubsystems/{subsystem}*\016nvmeSubsystems2\rnvmeSubsystem'
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['nqn']._options = None
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['nqn']._serialized_options = b'\342A\001\002'
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['serial_number']._options = None
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['serial_number']._serialized_options = b'\342A\001\001'
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['model_number']._options = None
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['model_number']._serialized_options = b'\342A\001\001'
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['max_namespaces']._options = None
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['max_namespaces']._serialized_options = b'\342A\001\001'
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['hostnqn']._options = None
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['hostnqn']._serialized_options = b'\342A\001\001'
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['psk']._options = None
  _globals['_NVMESUBSYSTEMSPEC'].fields_by_name['psk']._serialized_options = b'\342A\001\001'
  _globals['_NVMESUBSYSTEMSTATUS'].fields_by_name['firmware_revision']._options = None
  _globals['_NVMESUBSYSTEMSTATUS'].fields_by_name['firmware_revision']._serialized_options = b'\342A\001\003'
  _globals['_NVMESUBSYSTEMSTATUS'].fields_by_name['fru_guid']._options = None
  _globals['_NVMESUBSYSTEMSTATUS'].fields_by_name['fru_guid']._serialized_options = b'\342A\001\003'
  _globals['_NVMECONTROLLER'].fields_by_name['name']._options = None
  _globals['_NVMECONTROLLER'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NVMECONTROLLER'].fields_by_name['spec']._options = None
  _globals['_NVMECONTROLLER'].fields_by_name['spec']._serialized_options = b'\342A\001\002'
  _globals['_NVMECONTROLLER'].fields_by_name['status']._options = None
  _globals['_NVMECONTROLLER'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_NVMECONTROLLER']._options = None
  _globals['_NVMECONTROLLER']._serialized_options = b'\352A}\n!opi_api.storage.v1/NvmeController\0227nvmeSubsystems/{subsystem}/nvmeControllers/{controller}*\017nvmeControllers2\016nvmeController'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['nvme_controller_id']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['nvme_controller_id']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['trtype']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['trtype']._serialized_options = b'\342A\001\002'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['pcie_id']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['pcie_id']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['fabrics_id']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['fabrics_id']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_nsq']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_nsq']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_ncq']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_ncq']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['sqes']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['sqes']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['cqes']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['cqes']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_namespaces']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_namespaces']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['min_limit']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['min_limit']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_limit']._options = None
  _globals['_NVMECONTROLLERSPEC'].fields_by_name['max_limit']._serialized_options = b'\342A\001\001'
  _globals['_NVMECONTROLLERSTATUS'].fields_by_name['active']._options = None
  _globals['_NVMECONTROLLERSTATUS'].fields_by_name['active']._serialized_options = b'\342A\001\003'
  _globals['_NVMENAMESPACE'].fields_by_name['name']._options = None
  _globals['_NVMENAMESPACE'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_NVMENAMESPACE'].fields_by_name['spec']._options = None
  _globals['_NVMENAMESPACE'].fields_by_name['spec']._serialized_options = b'\342A\001\002'
  _globals['_NVMENAMESPACE'].fields_by_name['status']._options = None
  _globals['_NVMENAMESPACE'].fields_by_name['status']._serialized_options = b'\342A\001\003'
  _globals['_NVMENAMESPACE']._options = None
  _globals['_NVMENAMESPACE']._serialized_options = b'\352Ax\n opi_api.storage.v1/NvmeNamespace\0225nvmeSubsystems/{subsystem}/nvmeNamespaces/{namespace}*\016nvmeNamespaces2\rnvmeNamespace'
  _globals['_NVMENAMESPACESPEC'].fields_by_name['host_nsid']._options = None
  _globals['_NVMENAMESPACESPEC'].fields_by_name['host_nsid']._serialized_options = b'\342A\001\001'
  _globals['_NVMENAMESPACESPEC'].fields_by_name['nguid']._options = None
  _globals['_NVMENAMESPACESPEC'].fields_by_name['nguid']._serialized_options = b'\342A\001\001'
  _globals['_NVMENAMESPACESPEC'].fields_by_name['eui64']._options = None
  _globals['_NVMENAMESPACESPEC'].fields_by_name['eui64']._serialized_options = b'\342A\001\001'
  _globals['_NVMENAMESPACESPEC'].fields_by_name['uuid']._options = None
  _globals['_NVMENAMESPACESPEC'].fields_by_name['uuid']._serialized_options = b'\342A\001\001'
  _globals['_NVMENAMESPACESPEC'].fields_by_name['volume_name_ref']._options = None
  _globals['_NVMENAMESPACESPEC'].fields_by_name['volume_name_ref']._serialized_options = b'\342A\001\002'
  _globals['_NVMENAMESPACESTATUS'].fields_by_name['state']._options = None
  _globals['_NVMENAMESPACESTATUS'].fields_by_name['state']._serialized_options = b'\342A\001\003'
  _globals['_NVMENAMESPACESTATUS'].fields_by_name['oper_state']._options = None
  _globals['_NVMENAMESPACESTATUS'].fields_by_name['oper_state']._serialized_options = b'\342A\001\003'
  _globals['_CREATENVMESUBSYSTEMREQUEST'].fields_by_name['nvme_subsystem']._options = None
  _globals['_CREATENVMESUBSYSTEMREQUEST'].fields_by_name['nvme_subsystem']._serialized_options = b'\342A\001\002'
  _globals['_CREATENVMESUBSYSTEMREQUEST'].fields_by_name['nvme_subsystem_id']._options = None
  _globals['_CREATENVMESUBSYSTEMREQUEST'].fields_by_name['nvme_subsystem_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETENVMESUBSYSTEMREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENVMESUBSYSTEMREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeSubsystem'
  _globals['_DELETENVMESUBSYSTEMREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETENVMESUBSYSTEMREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMESUBSYSTEMREQUEST'].fields_by_name['nvme_subsystem']._options = None
  _globals['_UPDATENVMESUBSYSTEMREQUEST'].fields_by_name['nvme_subsystem']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENVMESUBSYSTEMREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENVMESUBSYSTEMREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMESUBSYSTEMREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENVMESUBSYSTEMREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMESUBSYSTEMSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNVMESUBSYSTEMSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMESUBSYSTEMSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNVMESUBSYSTEMSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNVMESUBSYSTEMREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNVMESUBSYSTEMREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeSubsystem'
  _globals['_STATSNVMESUBSYSTEMREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSNVMESUBSYSTEMREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeSubsystem'
  _globals['_CREATENVMECONTROLLERREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATENVMECONTROLLERREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeSubsystem'
  _globals['_CREATENVMECONTROLLERREQUEST'].fields_by_name['nvme_controller']._options = None
  _globals['_CREATENVMECONTROLLERREQUEST'].fields_by_name['nvme_controller']._serialized_options = b'\342A\001\002'
  _globals['_CREATENVMECONTROLLERREQUEST'].fields_by_name['nvme_controller_id']._options = None
  _globals['_CREATENVMECONTROLLERREQUEST'].fields_by_name['nvme_controller_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETENVMECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENVMECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A#\n!opi_api.storage.v1/NvmeController'
  _globals['_DELETENVMECONTROLLERREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETENVMECONTROLLERREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMECONTROLLERREQUEST'].fields_by_name['nvme_controller']._options = None
  _globals['_UPDATENVMECONTROLLERREQUEST'].fields_by_name['nvme_controller']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENVMECONTROLLERREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENVMECONTROLLERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMECONTROLLERREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENVMECONTROLLERREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMECONTROLLERSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTNVMECONTROLLERSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A#\022!opi_api.storage.v1/NvmeController'
  _globals['_LISTNVMECONTROLLERSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNVMECONTROLLERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMECONTROLLERSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNVMECONTROLLERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNVMECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNVMECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A#\n!opi_api.storage.v1/NvmeController'
  _globals['_STATSNVMECONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSNVMECONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A#\n!opi_api.storage.v1/NvmeController'
  _globals['_CREATENVMENAMESPACEREQUEST'].fields_by_name['parent']._options = None
  _globals['_CREATENVMENAMESPACEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeSubsystem'
  _globals['_CREATENVMENAMESPACEREQUEST'].fields_by_name['nvme_namespace']._options = None
  _globals['_CREATENVMENAMESPACEREQUEST'].fields_by_name['nvme_namespace']._serialized_options = b'\342A\001\002'
  _globals['_CREATENVMENAMESPACEREQUEST'].fields_by_name['nvme_namespace_id']._options = None
  _globals['_CREATENVMENAMESPACEREQUEST'].fields_by_name['nvme_namespace_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETENVMENAMESPACEREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETENVMENAMESPACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeNamespace'
  _globals['_DELETENVMENAMESPACEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETENVMENAMESPACEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMENAMESPACEREQUEST'].fields_by_name['nvme_namespace']._options = None
  _globals['_UPDATENVMENAMESPACEREQUEST'].fields_by_name['nvme_namespace']._serialized_options = b'\342A\001\002'
  _globals['_UPDATENVMENAMESPACEREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATENVMENAMESPACEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATENVMENAMESPACEREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATENVMENAMESPACEREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMENAMESPACESREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTNVMENAMESPACESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\022 opi_api.storage.v1/NvmeNamespace'
  _globals['_LISTNVMENAMESPACESREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTNVMENAMESPACESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTNVMENAMESPACESREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTNVMENAMESPACESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETNVMENAMESPACEREQUEST'].fields_by_name['name']._options = None
  _globals['_GETNVMENAMESPACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeNamespace'
  _globals['_STATSNVMENAMESPACEREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSNVMENAMESPACEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/NvmeNamespace'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['CreateNvmeSubsystem']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['CreateNvmeSubsystem']._serialized_options = b'\332A nvme_subsystem,nvme_subsystem_id\202\323\344\223\002$\"\022/v1/nvmeSubsystems:\016nvme_subsystem'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['DeleteNvmeSubsystem']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['DeleteNvmeSubsystem']._serialized_options = b'\332A\004name\202\323\344\223\002\035*\033/v1/{name=nvmeSubsystems/*}'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['UpdateNvmeSubsystem']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['UpdateNvmeSubsystem']._serialized_options = b'\332A\032nvme_subsystem,update_mask\202\323\344\223\002<2*/v1/{nvme_subsystem.name=nvmeSubsystems/*}:\016nvme_subsystem'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['ListNvmeSubsystems']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['ListNvmeSubsystems']._serialized_options = b'\202\323\344\223\002\024\022\022/v1/nvmeSubsystems'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['GetNvmeSubsystem']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['GetNvmeSubsystem']._serialized_options = b'\332A\004name\202\323\344\223\002\035\022\033/v1/{name=nvmeSubsystems/*}'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['StatsNvmeSubsystem']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['StatsNvmeSubsystem']._serialized_options = b'\332A\004name\202\323\344\223\002#\022!/v1/{name=nvmeSubsystems/*}:stats'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['CreateNvmeController']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['CreateNvmeController']._serialized_options = b'\332A)parent,nvme_controller,nvme_controller_id\202\323\344\223\002@\"-/v1/{parent=nvmeSubsystems/*}/nvmeControllers:\017nvme_controller'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['DeleteNvmeController']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['DeleteNvmeController']._serialized_options = b'\332A\004name\202\323\344\223\002/*-/v1/{name=nvmeSubsystems/*/nvmeControllers/*}'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['UpdateNvmeController']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['UpdateNvmeController']._serialized_options = b'\332A\033nvme_controller,update_mask\202\323\344\223\002P2=/v1/{nvme_controller.name=nvmeSubsystems/*/nvmeControllers/*}:\017nvme_controller'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['ListNvmeControllers']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['ListNvmeControllers']._serialized_options = b'\332A\006parent\202\323\344\223\002/\022-/v1/{parent=nvmeSubsystems/*}/nvmeControllers'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['GetNvmeController']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['GetNvmeController']._serialized_options = b'\332A\004name\202\323\344\223\002/\022-/v1/{name=nvmeSubsystems/*/nvmeControllers/*}'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['StatsNvmeController']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['StatsNvmeController']._serialized_options = b'\332A\004name\202\323\344\223\0025\0223/v1/{name=nvmeSubsystems/*/nvmeControllers/*}:stats'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['CreateNvmeNamespace']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['CreateNvmeNamespace']._serialized_options = b'\332A\'parent,nvme_namespace,nvme_namespace_id\202\323\344\223\002>\",/v1/{parent=nvmeSubsystems/*}/nvmeNamespaces:\016nvme_namespace'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['DeleteNvmeNamespace']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['DeleteNvmeNamespace']._serialized_options = b'\332A\004name\202\323\344\223\002.*,/v1/{name=nvmeSubsystems/*/nvmeNamespaces/*}'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['UpdateNvmeNamespace']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['UpdateNvmeNamespace']._serialized_options = b'\332A\032nvme_namespace,update_mask\202\323\344\223\002M2;/v1/{nvme_namespace.name=nvmeSubsystems/*/nvmeNamespaces/*}:\016nvme_namespace'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['ListNvmeNamespaces']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['ListNvmeNamespaces']._serialized_options = b'\332A\006parent\202\323\344\223\002.\022,/v1/{parent=nvmeSubsystems/*}/nvmeNamespaces'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['GetNvmeNamespace']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['GetNvmeNamespace']._serialized_options = b'\332A\004name\202\323\344\223\002.\022,/v1/{name=nvmeSubsystems/*/nvmeNamespaces/*}'
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['StatsNvmeNamespace']._options = None
  _globals['_FRONTENDNVMESERVICE'].methods_by_name['StatsNvmeNamespace']._serialized_options = b'\332A\004name\202\323\344\223\0024\0222/v1/{name=nvmeSubsystems/*/nvmeNamespaces/*}:stats'
  _globals['_NVMESUBSYSTEM']._serialized_start=239
  _globals['_NVMESUBSYSTEM']._serialized_end=514
  _globals['_NVMESUBSYSTEMSPEC']._serialized_start=517
  _globals['_NVMESUBSYSTEMSPEC']._serialized_end=745
  _globals['_NVMESUBSYSTEMSTATUS']._serialized_start=747
  _globals['_NVMESUBSYSTEMSTATUS']._serialized_end=852
  _globals['_NVMECONTROLLER']._serialized_start=855
  _globals['_NVMECONTROLLER']._serialized_end=1166
  _globals['_NVMECONTROLLERSPEC']._serialized_start=1169
  _globals['_NVMECONTROLLERSPEC']._serialized_end=1781
  _globals['_NVMECONTROLLERSTATUS']._serialized_start=1783
  _globals['_NVMECONTROLLERSTATUS']._serialized_end=1835
  _globals['_NVMENAMESPACE']._serialized_start=1838
  _globals['_NVMENAMESPACE']._serialized_end=2140
  _globals['_NVMENAMESPACESPEC']._serialized_start=2143
  _globals['_NVMENAMESPACESPEC']._serialized_end=2325
  _globals['_NVMENAMESPACESTATUS']._serialized_start=2328
  _globals['_NVMENAMESPACESTATUS']._serialized_end=2691
  _globals['_NVMENAMESPACESTATUS_STATE']._serialized_start=2514
  _globals['_NVMENAMESPACESTATUS_STATE']._serialized_end=2603
  _globals['_NVMENAMESPACESTATUS_OPERSTATE']._serialized_start=2605
  _globals['_NVMENAMESPACESTATUS_OPERSTATE']._serialized_end=2691
  _globals['_CREATENVMESUBSYSTEMREQUEST']._serialized_start=2694
  _globals['_CREATENVMESUBSYSTEMREQUEST']._serialized_end=2852
  _globals['_DELETENVMESUBSYSTEMREQUEST']._serialized_start=2855
  _globals['_DELETENVMESUBSYSTEMREQUEST']._serialized_end=2989
  _globals['_UPDATENVMESUBSYSTEMREQUEST']._serialized_start=2992
  _globals['_UPDATENVMESUBSYSTEMREQUEST']._serialized_end=3210
  _globals['_LISTNVMESUBSYSTEMSREQUEST']._serialized_start=3212
  _globals['_LISTNVMESUBSYSTEMSREQUEST']._serialized_end=3311
  _globals['_LISTNVMESUBSYSTEMSRESPONSE']._serialized_start=3314
  _globals['_LISTNVMESUBSYSTEMSRESPONSE']._serialized_end=3458
  _globals['_GETNVMESUBSYSTEMREQUEST']._serialized_start=3460
  _globals['_GETNVMESUBSYSTEMREQUEST']._serialized_end=3548
  _globals['_STATSNVMESUBSYSTEMREQUEST']._serialized_start=3550
  _globals['_STATSNVMESUBSYSTEMREQUEST']._serialized_end=3640
  _globals['_STATSNVMESUBSYSTEMRESPONSE']._serialized_start=3642
  _globals['_STATSNVMESUBSYSTEMRESPONSE']._serialized_end=3725
  _globals['_CREATENVMECONTROLLERREQUEST']._serialized_start=3728
  _globals['_CREATENVMECONTROLLERREQUEST']._serialized_end=3959
  _globals['_DELETENVMECONTROLLERREQUEST']._serialized_start=3962
  _globals['_DELETENVMECONTROLLERREQUEST']._serialized_end=4098
  _globals['_UPDATENVMECONTROLLERREQUEST']._serialized_start=4101
  _globals['_UPDATENVMECONTROLLERREQUEST']._serialized_end=4323
  _globals['_LISTNVMECONTROLLERSREQUEST']._serialized_start=4326
  _globals['_LISTNVMECONTROLLERSREQUEST']._serialized_end=4494
  _globals['_LISTNVMECONTROLLERSRESPONSE']._serialized_start=4497
  _globals['_LISTNVMECONTROLLERSRESPONSE']._serialized_end=4645
  _globals['_GETNVMECONTROLLERREQUEST']._serialized_start=4647
  _globals['_GETNVMECONTROLLERREQUEST']._serialized_end=4737
  _globals['_STATSNVMECONTROLLERREQUEST']._serialized_start=4739
  _globals['_STATSNVMECONTROLLERREQUEST']._serialized_end=4831
  _globals['_STATSNVMECONTROLLERRESPONSE']._serialized_start=4833
  _globals['_STATSNVMECONTROLLERRESPONSE']._serialized_end=4917
  _globals['_CREATENVMENAMESPACEREQUEST']._serialized_start=4920
  _globals['_CREATENVMENAMESPACEREQUEST']._serialized_end=5145
  _globals['_DELETENVMENAMESPACEREQUEST']._serialized_start=5148
  _globals['_DELETENVMENAMESPACEREQUEST']._serialized_end=5282
  _globals['_UPDATENVMENAMESPACEREQUEST']._serialized_start=5285
  _globals['_UPDATENVMENAMESPACEREQUEST']._serialized_end=5503
  _globals['_LISTNVMENAMESPACESREQUEST']._serialized_start=5506
  _globals['_LISTNVMENAMESPACESREQUEST']._serialized_end=5672
  _globals['_LISTNVMENAMESPACESRESPONSE']._serialized_start=5675
  _globals['_LISTNVMENAMESPACESRESPONSE']._serialized_end=5819
  _globals['_GETNVMENAMESPACEREQUEST']._serialized_start=5821
  _globals['_GETNVMENAMESPACEREQUEST']._serialized_end=5909
  _globals['_STATSNVMENAMESPACEREQUEST']._serialized_start=5911
  _globals['_STATSNVMENAMESPACEREQUEST']._serialized_end=6001
  _globals['_STATSNVMENAMESPACERESPONSE']._serialized_start=6003
  _globals['_STATSNVMENAMESPACERESPONSE']._serialized_end=6086
  _globals['_FRONTENDNVMESERVICE']._serialized_start=6089
  _globals['_FRONTENDNVMESERVICE']._serialized_end=9378
# @@protoc_insertion_point(module_scope)
