# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: frontend_virtio_scsi.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opicommon_pb2 as opicommon__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x66rontend_virtio_scsi.proto\x12\x12opi_api.storage.v1\x1a\x0fopicommon.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"\xb8\x01\n\x10VirtioScsiTarget\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12\x1f\n\x08max_luns\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x07maxLuns:i\xea\x41\x66\n#opi_api.storage.v1/VirtioScsiTarget\x12\x1avirtioScsiTargets/{volume}*\x11virtioScsiTargets2\x10virtioScsiTarget\"\xed\x02\n\x14VirtioScsiController\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12>\n\x07pcie_id\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.PciEndpointB\x04\xe2\x41\x01\x02R\x06pcieId\x12?\n\tmin_limit\x18\x03 \x01(\x0b\x32\x1c.opi_api.storage.v1.QosLimitB\x04\xe2\x41\x01\x01R\x08minLimit\x12?\n\tmax_limit\x18\x04 \x01(\x0b\x32\x1c.opi_api.storage.v1.QosLimitB\x04\xe2\x41\x01\x01R\x08maxLimit:y\xea\x41v\n\'opi_api.storage.v1/VirtioScsiController\x12\x1evirtioScsiControllers/{volume}*\x15virtioScsiControllers2\x14virtioScsiController\"\xe4\x01\n\rVirtioScsiLun\x12\x18\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x08R\x04name\x12,\n\x0ftarget_name_ref\x18\x02 \x01(\tB\x04\xe2\x41\x01\x02R\rtargetNameRef\x12,\n\x0fvolume_name_ref\x18\x03 \x01(\tB\x04\xe2\x41\x01\x02R\rvolumeNameRef:]\xea\x41Z\n opi_api.storage.v1/VirtioScsiLun\x12\x17virtioScsiLuns/{volume}*\x0evirtioScsiLuns2\rvirtioScsiLun\"\xb2\x01\n\x1d\x43reateVirtioScsiTargetRequest\x12X\n\x12virtio_scsi_target\x18\x01 \x01(\x0b\x32$.opi_api.storage.v1.VirtioScsiTargetB\x04\xe2\x41\x01\x02R\x10virtioScsiTarget\x12\x37\n\x15virtio_scsi_target_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x12virtioScsiTargetId\"\x8c\x01\n\x1d\x44\x65leteVirtioScsiTargetRequest\x12@\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#opi_api.storage.v1/VirtioScsiTargetR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xe7\x01\n\x1dUpdateVirtioScsiTargetRequest\x12X\n\x12virtio_scsi_target\x18\x01 \x01(\x0b\x32$.opi_api.storage.v1.VirtioScsiTargetB\x04\xe2\x41\x01\x02R\x10virtioScsiTarget\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xac\x01\n\x1cListVirtioScsiTargetsRequest\x12\x44\n\x06parent\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\x12#opi_api.storage.v1/VirtioScsiTargetR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x9d\x01\n\x1dListVirtioScsiTargetsResponse\x12T\n\x13virtio_scsi_targets\x18\x01 \x03(\x0b\x32$.opi_api.storage.v1.VirtioScsiTargetR\x11virtioScsiTargets\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"^\n\x1aGetVirtioScsiTargetRequest\x12@\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#opi_api.storage.v1/VirtioScsiTargetR\x04name\"`\n\x1cStatsVirtioScsiTargetRequest\x12@\n\x04name\x18\x01 \x01(\tB,\xe2\x41\x01\x02\xfa\x41%\n#opi_api.storage.v1/VirtioScsiTargetR\x04name\"V\n\x1dStatsVirtioScsiTargetResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats\"\xca\x01\n!CreateVirtioScsiControllerRequest\x12\x64\n\x16virtio_scsi_controller\x18\x01 \x01(\x0b\x32(.opi_api.storage.v1.VirtioScsiControllerB\x04\xe2\x41\x01\x02R\x14virtioScsiController\x12?\n\x19virtio_scsi_controller_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x16virtioScsiControllerId\"\x94\x01\n!DeleteVirtioScsiControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/VirtioScsiControllerR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xf7\x01\n!UpdateVirtioScsiControllerRequest\x12\x64\n\x16virtio_scsi_controller\x18\x01 \x01(\x0b\x32(.opi_api.storage.v1.VirtioScsiControllerB\x04\xe2\x41\x01\x02R\x14virtioScsiController\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xb4\x01\n ListVirtioScsiControllersRequest\x12H\n\x06parent\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\x12\'opi_api.storage.v1/VirtioScsiControllerR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\xad\x01\n!ListVirtioScsiControllersResponse\x12`\n\x17virtio_scsi_controllers\x18\x01 \x03(\x0b\x32(.opi_api.storage.v1.VirtioScsiControllerR\x15virtioScsiControllers\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"f\n\x1eGetVirtioScsiControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/VirtioScsiControllerR\x04name\"h\n StatsVirtioScsiControllerRequest\x12\x44\n\x04name\x18\x01 \x01(\tB0\xe2\x41\x01\x02\xfa\x41)\n\'opi_api.storage.v1/VirtioScsiControllerR\x04name\"Z\n!StatsVirtioScsiControllerResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats\"\xa0\x01\n\x1a\x43reateVirtioScsiLunRequest\x12O\n\x0fvirtio_scsi_lun\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.VirtioScsiLunB\x04\xe2\x41\x01\x02R\rvirtioScsiLun\x12\x31\n\x12virtio_scsi_lun_id\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x0fvirtioScsiLunId\"\x86\x01\n\x1a\x44\x65leteVirtioScsiLunRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/VirtioScsiLunR\x04name\x12)\n\rallow_missing\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xdb\x01\n\x1aUpdateVirtioScsiLunRequest\x12O\n\x0fvirtio_scsi_lun\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.VirtioScsiLunB\x04\xe2\x41\x01\x02R\rvirtioScsiLun\x12\x41\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01R\nupdateMask\x12)\n\rallow_missing\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01R\x0c\x61llowMissing\"\xa6\x01\n\x19ListVirtioScsiLunsRequest\x12\x41\n\x06parent\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\x12 opi_api.storage.v1/VirtioScsiLunR\x06parent\x12!\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01R\x08pageSize\x12#\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01R\tpageToken\"\x91\x01\n\x1aListVirtioScsiLunsResponse\x12K\n\x10virtio_scsi_luns\x18\x01 \x03(\x0b\x32!.opi_api.storage.v1.VirtioScsiLunR\x0evirtioScsiLuns\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"X\n\x17GetVirtioScsiLunRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/VirtioScsiLunR\x04name\"\x90\x01\n\x19StatsVirtioScsiLunRequest\x12=\n\x04name\x18\x01 \x01(\tB)\xe2\x41\x01\x02\xfa\x41\"\n opi_api.storage.v1/VirtioScsiLunR\x04name\x12\x34\n\x13\x63ontroller_name_ref\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01R\x11\x63ontrollerNameRef\"S\n\x1aStatsVirtioScsiLunResponse\x12\x35\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStatsR\x05stats2\x9c\x1a\n\x19\x46rontendVirtioScsiService\x12\xcf\x01\n\x16\x43reateVirtioScsiTarget\x12\x31.opi_api.storage.v1.CreateVirtioScsiTargetRequest\x1a$.opi_api.storage.v1.VirtioScsiTarget\"\\\xda\x41(virtio_scsi_target,virtio_scsi_target_id\x82\xd3\xe4\x93\x02+\"\x15/v1/virtioScsiTargets:\x12virtio_scsi_target\x12\x92\x01\n\x16\x44\x65leteVirtioScsiTarget\x12\x31.opi_api.storage.v1.DeleteVirtioScsiTargetRequest\x1a\x16.google.protobuf.Empty\"-\xda\x41\x04name\x82\xd3\xe4\x93\x02 *\x1e/v1/{name=virtioScsiTargets/*}\x12\xe1\x01\n\x16UpdateVirtioScsiTarget\x12\x31.opi_api.storage.v1.UpdateVirtioScsiTargetRequest\x1a$.opi_api.storage.v1.VirtioScsiTarget\"n\xda\x41\x1evirtio_scsi_target,update_mask\x82\xd3\xe4\x93\x02G21/v1/{virtio_scsi_target.name=virtioScsiTargets/*}:\x12virtio_scsi_target\x12\xad\x01\n\x15ListVirtioScsiTargets\x12\x30.opi_api.storage.v1.ListVirtioScsiTargetsRequest\x1a\x31.opi_api.storage.v1.ListVirtioScsiTargetsResponse\"/\xda\x41\x06parent\x82\xd3\xe4\x93\x02 \x12\x1e/v1/{parent=virtioScsiTargets}\x12\x9a\x01\n\x13GetVirtioScsiTarget\x12..opi_api.storage.v1.GetVirtioScsiTargetRequest\x1a$.opi_api.storage.v1.VirtioScsiTarget\"-\xda\x41\x04name\x82\xd3\xe4\x93\x02 \x12\x1e/v1/{name=virtioScsiTargets/*}\x12\xb1\x01\n\x15StatsVirtioScsiTarget\x12\x30.opi_api.storage.v1.StatsVirtioScsiTargetRequest\x1a\x31.opi_api.storage.v1.StatsVirtioScsiTargetResponse\"3\xda\x41\x04name\x82\xd3\xe4\x93\x02&\x12$/v1/{name=virtioScsiTargets/*}:stats\x12\xeb\x01\n\x1a\x43reateVirtioScsiController\x12\x35.opi_api.storage.v1.CreateVirtioScsiControllerRequest\x1a(.opi_api.storage.v1.VirtioScsiController\"l\xda\x41\x30virtio_scsi_controller,virtio_scsi_controller_id\x82\xd3\xe4\x93\x02\x33\"\x19/v1/virtioScsiControllers:\x16virtio_scsi_controller\x12\x9e\x01\n\x1a\x44\x65leteVirtioScsiController\x12\x35.opi_api.storage.v1.DeleteVirtioScsiControllerRequest\x1a\x16.google.protobuf.Empty\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$*\"/v1/{name=virtioScsiControllers/*}\x12\xfd\x01\n\x1aUpdateVirtioScsiController\x12\x35.opi_api.storage.v1.UpdateVirtioScsiControllerRequest\x1a(.opi_api.storage.v1.VirtioScsiController\"~\xda\x41\"virtio_scsi_controller,update_mask\x82\xd3\xe4\x93\x02S29/v1/{virtio_scsi_controller.name=virtioScsiControllers/*}:\x16virtio_scsi_controller\x12\xbd\x01\n\x19ListVirtioScsiControllers\x12\x34.opi_api.storage.v1.ListVirtioScsiControllersRequest\x1a\x35.opi_api.storage.v1.ListVirtioScsiControllersResponse\"3\xda\x41\x06parent\x82\xd3\xe4\x93\x02$\x12\"/v1/{parent=virtioScsiControllers}\x12\xaa\x01\n\x17GetVirtioScsiController\x12\x32.opi_api.storage.v1.GetVirtioScsiControllerRequest\x1a(.opi_api.storage.v1.VirtioScsiController\"1\xda\x41\x04name\x82\xd3\xe4\x93\x02$\x12\"/v1/{name=virtioScsiControllers/*}\x12\xc1\x01\n\x19StatsVirtioScsiController\x12\x34.opi_api.storage.v1.StatsVirtioScsiControllerRequest\x1a\x35.opi_api.storage.v1.StatsVirtioScsiControllerResponse\"7\xda\x41\x04name\x82\xd3\xe4\x93\x02*\x12(/v1/{name=virtioScsiControllers/*}:stats\x12\xba\x01\n\x13\x43reateVirtioScsiLun\x12..opi_api.storage.v1.CreateVirtioScsiLunRequest\x1a!.opi_api.storage.v1.VirtioScsiLun\"P\xda\x41\"virtio_scsi_lun,virtio_scsi_lun_id\x82\xd3\xe4\x93\x02%\"\x12/v1/virtioScsiLuns:\x0fvirtio_scsi_lun\x12\x89\x01\n\x13\x44\x65leteVirtioScsiLun\x12..opi_api.storage.v1.DeleteVirtioScsiLunRequest\x1a\x16.google.protobuf.Empty\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/{name=virtioScsiLuns/*}\x12\xcc\x01\n\x13UpdateVirtioScsiLun\x12..opi_api.storage.v1.UpdateVirtioScsiLunRequest\x1a!.opi_api.storage.v1.VirtioScsiLun\"b\xda\x41\x1bvirtio_scsi_lun,update_mask\x82\xd3\xe4\x93\x02>2+/v1/{virtio_scsi_lun.name=virtioScsiLuns/*}:\x0fvirtio_scsi_lun\x12\xa1\x01\n\x12ListVirtioScsiLuns\x12-.opi_api.storage.v1.ListVirtioScsiLunsRequest\x1a..opi_api.storage.v1.ListVirtioScsiLunsResponse\",\xda\x41\x06parent\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/{parent=virtioScsiLuns}\x12\x8e\x01\n\x10GetVirtioScsiLun\x12+.opi_api.storage.v1.GetVirtioScsiLunRequest\x1a!.opi_api.storage.v1.VirtioScsiLun\"*\xda\x41\x04name\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/{name=virtioScsiLuns/*}\x12\xa5\x01\n\x12StatsVirtioScsiLun\x12-.opi_api.storage.v1.StatsVirtioScsiLunRequest\x1a..opi_api.storage.v1.StatsVirtioScsiLunResponse\"0\xda\x41\x04name\x82\xd3\xe4\x93\x02#\x12!/v1/{name=virtioScsiLuns/*}:statsBf\n\x12opi_api.storage.v1B\x17\x46rontendVirtioScsiProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'frontend_virtio_scsi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022opi_api.storage.v1B\027FrontendVirtioScsiProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _globals['_VIRTIOSCSITARGET'].fields_by_name['name']._options = None
  _globals['_VIRTIOSCSITARGET'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_VIRTIOSCSITARGET'].fields_by_name['max_luns']._options = None
  _globals['_VIRTIOSCSITARGET'].fields_by_name['max_luns']._serialized_options = b'\342A\001\001'
  _globals['_VIRTIOSCSITARGET']._options = None
  _globals['_VIRTIOSCSITARGET']._serialized_options = b'\352Af\n#opi_api.storage.v1/VirtioScsiTarget\022\032virtioScsiTargets/{volume}*\021virtioScsiTargets2\020virtioScsiTarget'
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['name']._options = None
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['pcie_id']._options = None
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['pcie_id']._serialized_options = b'\342A\001\002'
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['min_limit']._options = None
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['min_limit']._serialized_options = b'\342A\001\001'
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['max_limit']._options = None
  _globals['_VIRTIOSCSICONTROLLER'].fields_by_name['max_limit']._serialized_options = b'\342A\001\001'
  _globals['_VIRTIOSCSICONTROLLER']._options = None
  _globals['_VIRTIOSCSICONTROLLER']._serialized_options = b'\352Av\n\'opi_api.storage.v1/VirtioScsiController\022\036virtioScsiControllers/{volume}*\025virtioScsiControllers2\024virtioScsiController'
  _globals['_VIRTIOSCSILUN'].fields_by_name['name']._options = None
  _globals['_VIRTIOSCSILUN'].fields_by_name['name']._serialized_options = b'\342A\001\010'
  _globals['_VIRTIOSCSILUN'].fields_by_name['target_name_ref']._options = None
  _globals['_VIRTIOSCSILUN'].fields_by_name['target_name_ref']._serialized_options = b'\342A\001\002'
  _globals['_VIRTIOSCSILUN'].fields_by_name['volume_name_ref']._options = None
  _globals['_VIRTIOSCSILUN'].fields_by_name['volume_name_ref']._serialized_options = b'\342A\001\002'
  _globals['_VIRTIOSCSILUN']._options = None
  _globals['_VIRTIOSCSILUN']._serialized_options = b'\352AZ\n opi_api.storage.v1/VirtioScsiLun\022\027virtioScsiLuns/{volume}*\016virtioScsiLuns2\rvirtioScsiLun'
  _globals['_CREATEVIRTIOSCSITARGETREQUEST'].fields_by_name['virtio_scsi_target']._options = None
  _globals['_CREATEVIRTIOSCSITARGETREQUEST'].fields_by_name['virtio_scsi_target']._serialized_options = b'\342A\001\002'
  _globals['_CREATEVIRTIOSCSITARGETREQUEST'].fields_by_name['virtio_scsi_target_id']._options = None
  _globals['_CREATEVIRTIOSCSITARGETREQUEST'].fields_by_name['virtio_scsi_target_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEVIRTIOSCSITARGETREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEVIRTIOSCSITARGETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#opi_api.storage.v1/VirtioScsiTarget'
  _globals['_DELETEVIRTIOSCSITARGETREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEVIRTIOSCSITARGETREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST'].fields_by_name['virtio_scsi_target']._options = None
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST'].fields_by_name['virtio_scsi_target']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOSCSITARGETSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTVIRTIOSCSITARGETSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A%\022#opi_api.storage.v1/VirtioScsiTarget'
  _globals['_LISTVIRTIOSCSITARGETSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTVIRTIOSCSITARGETSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOSCSITARGETSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTVIRTIOSCSITARGETSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETVIRTIOSCSITARGETREQUEST'].fields_by_name['name']._options = None
  _globals['_GETVIRTIOSCSITARGETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#opi_api.storage.v1/VirtioScsiTarget'
  _globals['_STATSVIRTIOSCSITARGETREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSVIRTIOSCSITARGETREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A%\n#opi_api.storage.v1/VirtioScsiTarget'
  _globals['_CREATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['virtio_scsi_controller']._options = None
  _globals['_CREATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['virtio_scsi_controller']._serialized_options = b'\342A\001\002'
  _globals['_CREATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['virtio_scsi_controller_id']._options = None
  _globals['_CREATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['virtio_scsi_controller_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/VirtioScsiController'
  _globals['_DELETEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['virtio_scsi_controller']._options = None
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['virtio_scsi_controller']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A)\022\'opi_api.storage.v1/VirtioScsiController'
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_GETVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/VirtioScsiController'
  _globals['_STATSVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSVIRTIOSCSICONTROLLERREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A)\n\'opi_api.storage.v1/VirtioScsiController'
  _globals['_CREATEVIRTIOSCSILUNREQUEST'].fields_by_name['virtio_scsi_lun']._options = None
  _globals['_CREATEVIRTIOSCSILUNREQUEST'].fields_by_name['virtio_scsi_lun']._serialized_options = b'\342A\001\002'
  _globals['_CREATEVIRTIOSCSILUNREQUEST'].fields_by_name['virtio_scsi_lun_id']._options = None
  _globals['_CREATEVIRTIOSCSILUNREQUEST'].fields_by_name['virtio_scsi_lun_id']._serialized_options = b'\342A\001\001'
  _globals['_DELETEVIRTIOSCSILUNREQUEST'].fields_by_name['name']._options = None
  _globals['_DELETEVIRTIOSCSILUNREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/VirtioScsiLun'
  _globals['_DELETEVIRTIOSCSILUNREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_DELETEVIRTIOSCSILUNREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOSCSILUNREQUEST'].fields_by_name['virtio_scsi_lun']._options = None
  _globals['_UPDATEVIRTIOSCSILUNREQUEST'].fields_by_name['virtio_scsi_lun']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEVIRTIOSCSILUNREQUEST'].fields_by_name['update_mask']._options = None
  _globals['_UPDATEVIRTIOSCSILUNREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEVIRTIOSCSILUNREQUEST'].fields_by_name['allow_missing']._options = None
  _globals['_UPDATEVIRTIOSCSILUNREQUEST'].fields_by_name['allow_missing']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOSCSILUNSREQUEST'].fields_by_name['parent']._options = None
  _globals['_LISTVIRTIOSCSILUNSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002\372A\"\022 opi_api.storage.v1/VirtioScsiLun'
  _globals['_LISTVIRTIOSCSILUNSREQUEST'].fields_by_name['page_size']._options = None
  _globals['_LISTVIRTIOSCSILUNSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTVIRTIOSCSILUNSREQUEST'].fields_by_name['page_token']._options = None
  _globals['_LISTVIRTIOSCSILUNSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_GETVIRTIOSCSILUNREQUEST'].fields_by_name['name']._options = None
  _globals['_GETVIRTIOSCSILUNREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/VirtioScsiLun'
  _globals['_STATSVIRTIOSCSILUNREQUEST'].fields_by_name['name']._options = None
  _globals['_STATSVIRTIOSCSILUNREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002\372A\"\n opi_api.storage.v1/VirtioScsiLun'
  _globals['_STATSVIRTIOSCSILUNREQUEST'].fields_by_name['controller_name_ref']._options = None
  _globals['_STATSVIRTIOSCSILUNREQUEST'].fields_by_name['controller_name_ref']._serialized_options = b'\342A\001\001'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['CreateVirtioScsiTarget']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['CreateVirtioScsiTarget']._serialized_options = b'\332A(virtio_scsi_target,virtio_scsi_target_id\202\323\344\223\002+\"\025/v1/virtioScsiTargets:\022virtio_scsi_target'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['DeleteVirtioScsiTarget']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['DeleteVirtioScsiTarget']._serialized_options = b'\332A\004name\202\323\344\223\002 *\036/v1/{name=virtioScsiTargets/*}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['UpdateVirtioScsiTarget']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['UpdateVirtioScsiTarget']._serialized_options = b'\332A\036virtio_scsi_target,update_mask\202\323\344\223\002G21/v1/{virtio_scsi_target.name=virtioScsiTargets/*}:\022virtio_scsi_target'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['ListVirtioScsiTargets']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['ListVirtioScsiTargets']._serialized_options = b'\332A\006parent\202\323\344\223\002 \022\036/v1/{parent=virtioScsiTargets}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['GetVirtioScsiTarget']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['GetVirtioScsiTarget']._serialized_options = b'\332A\004name\202\323\344\223\002 \022\036/v1/{name=virtioScsiTargets/*}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['StatsVirtioScsiTarget']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['StatsVirtioScsiTarget']._serialized_options = b'\332A\004name\202\323\344\223\002&\022$/v1/{name=virtioScsiTargets/*}:stats'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['CreateVirtioScsiController']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['CreateVirtioScsiController']._serialized_options = b'\332A0virtio_scsi_controller,virtio_scsi_controller_id\202\323\344\223\0023\"\031/v1/virtioScsiControllers:\026virtio_scsi_controller'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['DeleteVirtioScsiController']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['DeleteVirtioScsiController']._serialized_options = b'\332A\004name\202\323\344\223\002$*\"/v1/{name=virtioScsiControllers/*}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['UpdateVirtioScsiController']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['UpdateVirtioScsiController']._serialized_options = b'\332A\"virtio_scsi_controller,update_mask\202\323\344\223\002S29/v1/{virtio_scsi_controller.name=virtioScsiControllers/*}:\026virtio_scsi_controller'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['ListVirtioScsiControllers']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['ListVirtioScsiControllers']._serialized_options = b'\332A\006parent\202\323\344\223\002$\022\"/v1/{parent=virtioScsiControllers}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['GetVirtioScsiController']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['GetVirtioScsiController']._serialized_options = b'\332A\004name\202\323\344\223\002$\022\"/v1/{name=virtioScsiControllers/*}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['StatsVirtioScsiController']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['StatsVirtioScsiController']._serialized_options = b'\332A\004name\202\323\344\223\002*\022(/v1/{name=virtioScsiControllers/*}:stats'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['CreateVirtioScsiLun']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['CreateVirtioScsiLun']._serialized_options = b'\332A\"virtio_scsi_lun,virtio_scsi_lun_id\202\323\344\223\002%\"\022/v1/virtioScsiLuns:\017virtio_scsi_lun'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['DeleteVirtioScsiLun']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['DeleteVirtioScsiLun']._serialized_options = b'\332A\004name\202\323\344\223\002\035*\033/v1/{name=virtioScsiLuns/*}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['UpdateVirtioScsiLun']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['UpdateVirtioScsiLun']._serialized_options = b'\332A\033virtio_scsi_lun,update_mask\202\323\344\223\002>2+/v1/{virtio_scsi_lun.name=virtioScsiLuns/*}:\017virtio_scsi_lun'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['ListVirtioScsiLuns']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['ListVirtioScsiLuns']._serialized_options = b'\332A\006parent\202\323\344\223\002\035\022\033/v1/{parent=virtioScsiLuns}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['GetVirtioScsiLun']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['GetVirtioScsiLun']._serialized_options = b'\332A\004name\202\323\344\223\002\035\022\033/v1/{name=virtioScsiLuns/*}'
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['StatsVirtioScsiLun']._options = None
  _globals['_FRONTENDVIRTIOSCSISERVICE'].methods_by_name['StatsVirtioScsiLun']._serialized_options = b'\332A\004name\202\323\344\223\002#\022!/v1/{name=virtioScsiLuns/*}:stats'
  _globals['_VIRTIOSCSITARGET']._serialized_start=246
  _globals['_VIRTIOSCSITARGET']._serialized_end=430
  _globals['_VIRTIOSCSICONTROLLER']._serialized_start=433
  _globals['_VIRTIOSCSICONTROLLER']._serialized_end=798
  _globals['_VIRTIOSCSILUN']._serialized_start=801
  _globals['_VIRTIOSCSILUN']._serialized_end=1029
  _globals['_CREATEVIRTIOSCSITARGETREQUEST']._serialized_start=1032
  _globals['_CREATEVIRTIOSCSITARGETREQUEST']._serialized_end=1210
  _globals['_DELETEVIRTIOSCSITARGETREQUEST']._serialized_start=1213
  _globals['_DELETEVIRTIOSCSITARGETREQUEST']._serialized_end=1353
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST']._serialized_start=1356
  _globals['_UPDATEVIRTIOSCSITARGETREQUEST']._serialized_end=1587
  _globals['_LISTVIRTIOSCSITARGETSREQUEST']._serialized_start=1590
  _globals['_LISTVIRTIOSCSITARGETSREQUEST']._serialized_end=1762
  _globals['_LISTVIRTIOSCSITARGETSRESPONSE']._serialized_start=1765
  _globals['_LISTVIRTIOSCSITARGETSRESPONSE']._serialized_end=1922
  _globals['_GETVIRTIOSCSITARGETREQUEST']._serialized_start=1924
  _globals['_GETVIRTIOSCSITARGETREQUEST']._serialized_end=2018
  _globals['_STATSVIRTIOSCSITARGETREQUEST']._serialized_start=2020
  _globals['_STATSVIRTIOSCSITARGETREQUEST']._serialized_end=2116
  _globals['_STATSVIRTIOSCSITARGETRESPONSE']._serialized_start=2118
  _globals['_STATSVIRTIOSCSITARGETRESPONSE']._serialized_end=2204
  _globals['_CREATEVIRTIOSCSICONTROLLERREQUEST']._serialized_start=2207
  _globals['_CREATEVIRTIOSCSICONTROLLERREQUEST']._serialized_end=2409
  _globals['_DELETEVIRTIOSCSICONTROLLERREQUEST']._serialized_start=2412
  _globals['_DELETEVIRTIOSCSICONTROLLERREQUEST']._serialized_end=2560
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST']._serialized_start=2563
  _globals['_UPDATEVIRTIOSCSICONTROLLERREQUEST']._serialized_end=2810
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST']._serialized_start=2813
  _globals['_LISTVIRTIOSCSICONTROLLERSREQUEST']._serialized_end=2993
  _globals['_LISTVIRTIOSCSICONTROLLERSRESPONSE']._serialized_start=2996
  _globals['_LISTVIRTIOSCSICONTROLLERSRESPONSE']._serialized_end=3169
  _globals['_GETVIRTIOSCSICONTROLLERREQUEST']._serialized_start=3171
  _globals['_GETVIRTIOSCSICONTROLLERREQUEST']._serialized_end=3273
  _globals['_STATSVIRTIOSCSICONTROLLERREQUEST']._serialized_start=3275
  _globals['_STATSVIRTIOSCSICONTROLLERREQUEST']._serialized_end=3379
  _globals['_STATSVIRTIOSCSICONTROLLERRESPONSE']._serialized_start=3381
  _globals['_STATSVIRTIOSCSICONTROLLERRESPONSE']._serialized_end=3471
  _globals['_CREATEVIRTIOSCSILUNREQUEST']._serialized_start=3474
  _globals['_CREATEVIRTIOSCSILUNREQUEST']._serialized_end=3634
  _globals['_DELETEVIRTIOSCSILUNREQUEST']._serialized_start=3637
  _globals['_DELETEVIRTIOSCSILUNREQUEST']._serialized_end=3771
  _globals['_UPDATEVIRTIOSCSILUNREQUEST']._serialized_start=3774
  _globals['_UPDATEVIRTIOSCSILUNREQUEST']._serialized_end=3993
  _globals['_LISTVIRTIOSCSILUNSREQUEST']._serialized_start=3996
  _globals['_LISTVIRTIOSCSILUNSREQUEST']._serialized_end=4162
  _globals['_LISTVIRTIOSCSILUNSRESPONSE']._serialized_start=4165
  _globals['_LISTVIRTIOSCSILUNSRESPONSE']._serialized_end=4310
  _globals['_GETVIRTIOSCSILUNREQUEST']._serialized_start=4312
  _globals['_GETVIRTIOSCSILUNREQUEST']._serialized_end=4400
  _globals['_STATSVIRTIOSCSILUNREQUEST']._serialized_start=4403
  _globals['_STATSVIRTIOSCSILUNREQUEST']._serialized_end=4547
  _globals['_STATSVIRTIOSCSILUNRESPONSE']._serialized_start=4549
  _globals['_STATSVIRTIOSCSILUNRESPONSE']._serialized_end=4632
  _globals['_FRONTENDVIRTIOSCSISERVICE']._serialized_start=4635
  _globals['_FRONTENDVIRTIOSCSISERVICE']._serialized_end=7991
# @@protoc_insertion_point(module_scope)
