# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nexthop.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rnexthop.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\xe6\x01\n\x07NextHop\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12?\n\x04spec\x18\x02 \x01(\x0b\x32+.opi_api.network.cloud.v1alpha1.NextHopSpecR\x04spec\x12\x45\n\x06status\x18\x03 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.NextHopStatusR\x06status:?\xea\x41<\n&opi_api.network.cloud.v1alpha1/nexthop\x12\x12nexthops/{nexthop}\"\xa5\x02\n\x0bNextHopSpec\x12\\\n\x0foverlay_nh_info\x18\x01 \x01(\x0b\x32\x32.opi_api.network.cloud.v1alpha1.OverlayNextHopSpecH\x00R\roverlayNhInfo\x12_\n\x10underlay_nh_info\x18\x02 \x01(\x0b\x32\x33.opi_api.network.cloud.v1alpha1.UnderlayNextHopSpecH\x00R\x0eunderlayNhInfo\x12M\n\nip_nh_info\x18\x03 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.IPNextHopSpecH\x00R\x08ipNhInfoB\x08\n\x06nhinfo\"k\n\x13UnderlayNextHopSpec\x12,\n\x12interface_name_ref\x18\x01 \x01(\tR\x10interfaceNameRef\x12&\n\x0funderlay_nh_mac\x18\x02 \x01(\x0cR\runderlayNhMac\"<\n\x12OverlayNextHopSpec\x12&\n\x0ftunnel_name_ref\x18\x01 \x01(\tR\rtunnelNameRef\"\xa8\x01\n\rIPNextHopSpec\x12 \n\x0cvpc_name_ref\x18\x01 \x01(\tR\nvpcNameRef\x12O\n\nip_address\x18\x02 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\tipAddress\x12\x12\n\x04vlan\x18\x03 \x01(\x05R\x04vlan\x12\x10\n\x03mac\x18\x04 \x01(\x0cR\x03mac\"\xaa\x02\n\rNextHopStatus\x12L\n\thw_handle\x18\x01 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x08hwHandle\x12\x61\n\x10underlay_nh_info\x18\x02 \x01(\x0b\x32\x35.opi_api.network.cloud.v1alpha1.UnderlayNextHopStatusH\x00R\x0eunderlayNhInfo\x12^\n\x0foverlay_nh_info\x18\x03 \x01(\x0b\x32\x34.opi_api.network.cloud.v1alpha1.OverlayNextHopStatusH\x00R\roverlayNhInfoB\x08\n\x06nhinfo\"?\n\x15UnderlayNextHopStatus\x12\x12\n\x04port\x18\x01 \x01(\x05R\x04port\x12\x12\n\x04vlan\x18\x02 \x01(\x05R\x04vlan\"e\n\x14OverlayNextHopStatus\x12M\n\ttunnel_ip\x18\x01 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x08tunnelIp\"\x7f\n\rNextHopLookup\x12\x41\n\x04type\x18\x01 \x01(\x0e\x32+.opi_api.network.cloud.v1alpha1.NextHopTypeH\x00R\x04type\x12 \n\x0bnh_name_ref\x18\x02 \x01(\tH\x00R\tnhNameRefB\t\n\x07gettype\"\x84\x02\n\x0cNextHopGroup\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x44\n\x04spec\x18\x02 \x01(\x0b\x32\x30.opi_api.network.cloud.v1alpha1.NextHopGroupSpecR\x04spec\x12J\n\x06status\x18\x03 \x01(\x0b\x32\x32.opi_api.network.cloud.v1alpha1.NextHopGroupStatusR\x06status:N\xea\x41K\n+opi_api.network.cloud.v1alpha1/nexthopgroup\x12\x1cnexthopgroups/{nexthopgroup}\"\x9f\x01\n\x10NextHopGroupSpec\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x30.opi_api.network.cloud.v1alpha1.NextHopGroupTypeR\x04type\x12\x45\n\x07members\x18\x02 \x03(\x0b\x32+.opi_api.network.cloud.v1alpha1.NextHopSpecR\x07members\"\xab\x01\n\x12NextHopGroupStatus\x12G\n\x07members\x18\x01 \x03(\x0b\x32-.opi_api.network.cloud.v1alpha1.NextHopStatusR\x07members\x12L\n\thw_handle\x18\x02 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x08hwHandle\"\x94\x01\n\x12NextHopGroupLookup\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x30.opi_api.network.cloud.v1alpha1.NextHopGroupTypeH\x00R\x04type\x12+\n\x11nh_group_name_ref\x18\x02 \x01(\tH\x00R\x0enhGroupNameRefB\t\n\x07gettype*y\n\x0bNextHopType\x12\x1d\n\x19NEXT_HOP_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10NEXT_HOP_TYPE_IP\x10\x01\x12\x1a\n\x16NEXT_HOP_TYPE_UNDERLAY\x10\x02\x12\x19\n\x15NEXT_HOP_TYPE_OVERLAY\x10\x03*\x84\x01\n\x10NextHopGroupType\x12#\n\x1fNEXT_HOP_GROUP_TYPE_UNSPECIFIED\x10\x00\x12$\n NEXT_HOP_GROUP_TYPE_OVERLAY_ECMP\x10\x01\x12%\n!NEXT_HOP_GROUP_TYPE_UNDERLAY_ECMP\x10\x02\x42m\n\x1eopi_api.network.cloud.v1alpha1B\x0cNextHopProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nexthop_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\014NextHopProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_NEXTHOP']._options = None
  _globals['_NEXTHOP']._serialized_options = b'\352A<\n&opi_api.network.cloud.v1alpha1/nexthop\022\022nexthops/{nexthop}'
  _globals['_NEXTHOPGROUP']._options = None
  _globals['_NEXTHOPGROUP']._serialized_options = b'\352AK\n+opi_api.network.cloud.v1alpha1/nexthopgroup\022\034nexthopgroups/{nexthopgroup}'
  _globals['_NEXTHOPTYPE']._serialized_start=2315
  _globals['_NEXTHOPTYPE']._serialized_end=2436
  _globals['_NEXTHOPGROUPTYPE']._serialized_start=2439
  _globals['_NEXTHOPGROUPTYPE']._serialized_end=2571
  _globals['_NEXTHOP']._serialized_start=97
  _globals['_NEXTHOP']._serialized_end=327
  _globals['_NEXTHOPSPEC']._serialized_start=330
  _globals['_NEXTHOPSPEC']._serialized_end=623
  _globals['_UNDERLAYNEXTHOPSPEC']._serialized_start=625
  _globals['_UNDERLAYNEXTHOPSPEC']._serialized_end=732
  _globals['_OVERLAYNEXTHOPSPEC']._serialized_start=734
  _globals['_OVERLAYNEXTHOPSPEC']._serialized_end=794
  _globals['_IPNEXTHOPSPEC']._serialized_start=797
  _globals['_IPNEXTHOPSPEC']._serialized_end=965
  _globals['_NEXTHOPSTATUS']._serialized_start=968
  _globals['_NEXTHOPSTATUS']._serialized_end=1266
  _globals['_UNDERLAYNEXTHOPSTATUS']._serialized_start=1268
  _globals['_UNDERLAYNEXTHOPSTATUS']._serialized_end=1331
  _globals['_OVERLAYNEXTHOPSTATUS']._serialized_start=1333
  _globals['_OVERLAYNEXTHOPSTATUS']._serialized_end=1434
  _globals['_NEXTHOPLOOKUP']._serialized_start=1436
  _globals['_NEXTHOPLOOKUP']._serialized_end=1563
  _globals['_NEXTHOPGROUP']._serialized_start=1566
  _globals['_NEXTHOPGROUP']._serialized_end=1826
  _globals['_NEXTHOPGROUPSPEC']._serialized_start=1829
  _globals['_NEXTHOPGROUPSPEC']._serialized_end=1988
  _globals['_NEXTHOPGROUPSTATUS']._serialized_start=1991
  _globals['_NEXTHOPGROUPSTATUS']._serialized_end=2162
  _globals['_NEXTHOPGROUPLOOKUP']._serialized_start=2165
  _globals['_NEXTHOPGROUPLOOKUP']._serialized_end=2313
# @@protoc_insertion_point(module_scope)
