# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: networkpolicy.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13networkpolicy.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\x90\x02\n\x0eSecurityPolicy\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x46\n\x04spec\x18\x02 \x01(\x0b\x32\x32.opi_api.network.cloud.v1alpha1.SecurityPolicySpecR\x04spec\x12L\n\x06status\x18\x03 \x01(\x0b\x32\x34.opi_api.network.cloud.v1alpha1.SecurityPolicyStatusR\x06status:T\xea\x41Q\n-opi_api.network.cloud.v1alpha1/securitypolicy\x12 securitypolicys/{securitypolicy}\"\xdc\x03\n\x12SecurityPolicySpec\x12\x46\n\x04type\x18\x01 \x01(\x0e\x32\x32.opi_api.network.cloud.v1alpha1.SecurityPolicyTypeR\x04type\x12R\n\x0e\x61\x64\x64ress_family\x18\x02 \x01(\x0e\x32+.opi_api.network.opinetcommon.v1alpha1.IpAfR\raddressFamily\x12\x1c\n\tstateless\x18\x03 \x01(\x08R\tstateless\x12q\n\x17\x64\x65\x66\x61ult_security_action\x18\x04 \x01(\x0e\x32\x39.opi_api.network.opinetcommon.v1alpha1.SecurityRuleActionR\x15\x64\x65\x66\x61ultSecurityAction\x12\x46\n\x05rules\x18\x05 \x03(\x0b\x32\x30.opi_api.network.cloud.v1alpha1.SecurityRuleInfoR\x05rules\x12Q\n\x0brule_format\x18\x06 \x01(\x0e\x32\x30.opi_api.network.cloud.v1alpha1.PolicyRuleFormatR\nruleFormat\"x\n\x10SecurityRuleInfo\x12\x1b\n\trule_name\x18\x01 \x01(\tR\x08ruleName\x12G\n\x05\x61ttrs\x18\x02 \x01(\x0b\x32\x31.opi_api.network.cloud.v1alpha1.SecurityRuleAttrsR\x05\x61ttrs\"\xb0\x02\n\x11SecurityRuleAttrs\x12\x1a\n\x08priority\x18\x01 \x01(\x05R\x08priority\x12\x46\n\x05match\x18\x02 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.RuleMatchR\x05match\x12Q\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x39.opi_api.network.opinetcommon.v1alpha1.SecurityRuleActionR\x06\x61\x63tion\x12 \n\x0bterminating\x18\x04 \x01(\x08R\x0bterminating\x12\x42\n\x08\x61lg_spec\x18\x05 \x01(\x0b\x32\'.opi_api.network.cloud.v1alpha1.ALGSpecR\x07\x61lgSpec\"8\n\nFTPOptions\x12*\n\x11\x61llow_ip_mismatch\x18\x01 \x01(\x08R\x0f\x61llowIpMismatch\"\xce\x02\n\nDNSOptions\x12\x39\n\x19\x64rop_multi_query_messages\x18\x01 \x01(\x08R\x16\x64ropMultiQueryMessages\x12:\n\x1a\x64rop_large_domain_name_ref\x18\x02 \x01(\x08R\x16\x64ropLargeDomainNameRef\x12\x37\n\x18\x64rop_long_label_messages\x18\x03 \x01(\x08R\x15\x64ropLongLabelMessages\x12\x37\n\x18\x64rop_multi_zone_messages\x18\x04 \x01(\x08R\x15\x64ropMultiZoneMessages\x12)\n\x10response_timeout\x18\x05 \x01(\x05R\x0fresponseTimeout\x12,\n\x12max_message_length\x18\x06 \x01(\x05R\x10maxMessageLength\"-\n\x0cMSRPCOptions\x12\x1d\n\nprogram_id\x18\x01 \x03(\x0cR\tprogramId\".\n\rSunRPCOptions\x12\x1d\n\nprogram_id\x18\x01 \x03(\x0cR\tprogramId\"\xca\x03\n\x07\x41LGSpec\x12\x42\n\x08\x61lg_type\x18\x01 \x01(\x0e\x32\'.opi_api.network.cloud.v1alpha1.ALGTypeR\x07\x61lgType\x12!\n\x0cidle_timeout\x18\x02 \x01(\x05R\x0bidleTimeout\x12M\n\x0b\x66tp_options\x18\x03 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.FTPOptionsH\x00R\nftpOptions\x12M\n\x0b\x64ns_options\x18\x04 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.DNSOptionsH\x00R\ndnsOptions\x12S\n\rmsrpc_options\x18\x05 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.MSRPCOptionsH\x00R\x0cmsrpcOptions\x12V\n\x0esunrpc_options\x18\x06 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.SunRPCOptionsH\x00R\rsunrpcOptionsB\r\n\x0b\x61lg_options\"\xe9\x02\n\x14SecurityPolicyStatus\x12\x1d\n\nrule_count\x18\x01 \x01(\x05R\truleCount\x12\x1b\n\tvpc_count\x18\x02 \x01(\x05R\x08vpcCount\x12!\n\x0csubnet_count\x18\x03 \x01(\x05R\x0bsubnetCount\x12\x1d\n\nvnic_count\x18\x04 \x01(\x05R\tvnicCount\x12U\n\x0ehw_pool_handle\x18\x05 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x0chwPoolHandle\x12L\n\thw_handle\x18\x06 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x08hwHandle\x12.\n\x13policy_base_address\x18\x07 \x01(\x04R\x11policyBaseAddress\"\x84\x02\n\x0cSecurityRule\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x44\n\x04spec\x18\x02 \x01(\x0b\x32\x30.opi_api.network.cloud.v1alpha1.SecurityRuleSpecR\x04spec\x12J\n\x06status\x18\x03 \x01(\x0b\x32\x32.opi_api.network.cloud.v1alpha1.SecurityRuleStatusR\x06status:N\xea\x41K\n+opi_api.network.cloud.v1alpha1/securityrule\x12\x1csecurityrules/{securityrule}\"\x94\x01\n\x10SecurityRuleSpec\x12\x37\n\x18security_policy_name_ref\x18\x01 \x01(\tR\x15securityPolicyNameRef\x12G\n\x05\x61ttrs\x18\x02 \x01(\x0b\x32\x31.opi_api.network.cloud.v1alpha1.SecurityRuleAttrsR\x05\x61ttrs\"\x14\n\x12SecurityRuleStatus\"\x96\x02\n\x0fSecurityProfile\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12G\n\x04spec\x18\x02 \x01(\x0b\x32\x33.opi_api.network.cloud.v1alpha1.SecurityProfileSpecR\x04spec\x12M\n\x06status\x18\x03 \x01(\x0b\x32\x35.opi_api.network.cloud.v1alpha1.SecurityProfileStatusR\x06status:W\xea\x41T\n.opi_api.network.cloud.v1alpha1/securityprofile\x12\"securityprofiles/{securityprofile}\"\xf0\x05\n\x13SecurityProfileSpec\x12<\n\x1a\x63onnection_tracking_enable\x18\x01 \x01(\x08R\x18\x63onnectionTrackingEnable\x12*\n\x11rule_stats_enable\x18\x02 \x01(\x08R\x0fruleStatsEnable\x12q\n\x17\x64\x65\x66\x61ult_firewall_action\x18\x03 \x01(\x0e\x32\x39.opi_api.network.opinetcommon.v1alpha1.SecurityRuleActionR\x15\x64\x65\x66\x61ultFirewallAction\x12(\n\x10tcp_idle_timeout\x18\x04 \x01(\x05R\x0etcpIdleTimeout\x12(\n\x10udp_idle_timeout\x18\x05 \x01(\x05R\x0eudpIdleTimeout\x12*\n\x11icmp_idle_timeout\x18\x06 \x01(\x05R\x0ficmpIdleTimeout\x12,\n\x12other_idle_timeout\x18\x07 \x01(\x05R\x10otherIdleTimeout\x12?\n\x1ctcp_connection_setup_timeout\x18\x08 \x01(\x05R\x19tcpConnectionSetupTimeout\x12\x33\n\x16tcp_half_close_timeout\x18\t \x01(\x05R\x13tcpHalfCloseTimeout\x12*\n\x11tcp_close_timeout\x18\n \x01(\x05R\x0ftcpCloseTimeout\x12(\n\x10tcp_dorp_timeout\x18\x0b \x01(\x05R\x0etcpDorpTimeout\x12(\n\x10udp_drop_timeout\x18\x0c \x01(\x05R\x0eudpDropTimeout\x12*\n\x11icmp_drop_timeout\x18\r \x01(\x05R\x0ficmpDropTimeout\x12,\n\x12other_drop_timeout\x18\x0e \x01(\x05R\x10otherDropTimeout\"\x17\n\x15SecurityProfileStatus\"\xa9\x03\n\x11PolicyLookupMatch\x12M\n\tsource_ip\x18\x01 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x08sourceIp\x12\x1f\n\x0bsource_tags\x18\x02 \x03(\rR\nsourceTags\x12W\n\x0e\x64\x65stination_ip\x18\x03 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\rdestinationIp\x12)\n\x10\x64\x65stination_tags\x18\x04 \x03(\rR\x0f\x64\x65stinationTags\x12\x1a\n\x08protocol\x18\x05 \x01(\x05R\x08protocol\x12\x1f\n\x0bsource_port\x18\x06 \x01(\x05R\nsourcePort\x12)\n\x10\x64\x65stination_port\x18\x07 \x01(\x05R\x0f\x64\x65stinationPort\x12\x1b\n\ticmp_type\x18\x08 \x01(\x05R\x08icmpType\x12\x1b\n\ticmp_code\x18\t \x01(\x05R\x08icmpCode\"\x8c\x04\n\x1bSecurityPolicyLookupRequest\x12(\n\x0fpolicy_name_ref\x18\x01 \x01(\tH\x00R\rpolicyNameRef\x12v\n\x10vnic_lookup_info\x18\x02 \x01(\x0b\x32J.opi_api.network.cloud.v1alpha1.SecurityPolicyLookupRequest.VnicLookupInfoH\x00R\x0evnicLookupInfo\x12T\n\x0cmatch_fields\x18\x03 \x01(\x0b\x32\x31.opi_api.network.cloud.v1alpha1.PolicyLookupMatchR\x0bmatchFields\x1a\xe5\x01\n\x0eVnicLookupInfo\x12\"\n\rvnic_name_ref\x18\x01 \x01(\tR\x0bvnicNameRef\x12[\n\x10policy_direction\x18\x02 \x01(\x0e\x32\x30.opi_api.network.opinetcommon.v1alpha1.PolicyDirR\x0fpolicyDirection\x12R\n\x0e\x61\x64\x64ress_family\x18\x03 \x01(\x0e\x32+.opi_api.network.opinetcommon.v1alpha1.IpAfR\raddressFamilyB\r\n\x0blookup_info\"\xc0\x02\n\x12PolicyLookupResult\x12U\n\x0erule_hw_handle\x18\x01 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x0cruleHwHandle\x12\x1a\n\x08priority\x18\x02 \x01(\x05R\x08priority\x12Q\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x39.opi_api.network.opinetcommon.v1alpha1.SecurityRuleActionR\x06\x61\x63tion\x12\x42\n\x08\x61lg_type\x18\x04 \x01(\x0e\x32\'.opi_api.network.cloud.v1alpha1.ALGTypeR\x07\x61lgType\x12 \n\x0bterminating\x18\x05 \x01(\x08R\x0bterminating*~\n\x12SecurityPolicyType\x12$\n SECURITY_POLICY_TYPE_UNSPECIFIED\x10\x00\x12!\n\x1dSECURITY_POLICY_TYPE_UNDERLAY\x10\x01\x12\x1f\n\x1bSECURITY_POLICY_TYPE_TENANT\x10\x02*\x96\x01\n\x07\x41LGType\x12\x18\n\x14\x41LG_TYPE_UNSPECIFIED\x10\x00\x12\x11\n\rALG_TYPE_TFTP\x10\x01\x12\x10\n\x0c\x41LG_TYPE_FTP\x10\x02\x12\x10\n\x0c\x41LG_TYPE_DNS\x10\x03\x12\x13\n\x0f\x41LG_TYPE_SUNRPC\x10\x04\x12\x12\n\x0e\x41LG_TYPE_MSRPC\x10\x05\x12\x11\n\rALG_TYPE_RTSP\x10\x06*x\n\x10PolicyRuleFormat\x12\"\n\x1ePOLICY_RULE_FORMAT_UNSPECIFIED\x10\x00\x12 \n\x1cPOLICY_RULE_FORMAT_FLATTENED\x10\x01\x12\x1e\n\x1aPOLICY_RULE_FORMAT_COMPACT\x10\x02\x42s\n\x1eopi_api.network.cloud.v1alpha1B\x12NetworkPolicyProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'networkpolicy_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\022NetworkPolicyProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_SECURITYPOLICY']._options = None
  _globals['_SECURITYPOLICY']._serialized_options = b'\352AQ\n-opi_api.network.cloud.v1alpha1/securitypolicy\022 securitypolicys/{securitypolicy}'
  _globals['_SECURITYRULE']._options = None
  _globals['_SECURITYRULE']._serialized_options = b'\352AK\n+opi_api.network.cloud.v1alpha1/securityrule\022\034securityrules/{securityrule}'
  _globals['_SECURITYPROFILE']._options = None
  _globals['_SECURITYPROFILE']._serialized_options = b'\352AT\n.opi_api.network.cloud.v1alpha1/securityprofile\022\"securityprofiles/{securityprofile}'
  _globals['_SECURITYPOLICYTYPE']._serialized_start=5375
  _globals['_SECURITYPOLICYTYPE']._serialized_end=5501
  _globals['_ALGTYPE']._serialized_start=5504
  _globals['_ALGTYPE']._serialized_end=5654
  _globals['_POLICYRULEFORMAT']._serialized_start=5656
  _globals['_POLICYRULEFORMAT']._serialized_end=5776
  _globals['_SECURITYPOLICY']._serialized_start=103
  _globals['_SECURITYPOLICY']._serialized_end=375
  _globals['_SECURITYPOLICYSPEC']._serialized_start=378
  _globals['_SECURITYPOLICYSPEC']._serialized_end=854
  _globals['_SECURITYRULEINFO']._serialized_start=856
  _globals['_SECURITYRULEINFO']._serialized_end=976
  _globals['_SECURITYRULEATTRS']._serialized_start=979
  _globals['_SECURITYRULEATTRS']._serialized_end=1283
  _globals['_FTPOPTIONS']._serialized_start=1285
  _globals['_FTPOPTIONS']._serialized_end=1341
  _globals['_DNSOPTIONS']._serialized_start=1344
  _globals['_DNSOPTIONS']._serialized_end=1678
  _globals['_MSRPCOPTIONS']._serialized_start=1680
  _globals['_MSRPCOPTIONS']._serialized_end=1725
  _globals['_SUNRPCOPTIONS']._serialized_start=1727
  _globals['_SUNRPCOPTIONS']._serialized_end=1773
  _globals['_ALGSPEC']._serialized_start=1776
  _globals['_ALGSPEC']._serialized_end=2234
  _globals['_SECURITYPOLICYSTATUS']._serialized_start=2237
  _globals['_SECURITYPOLICYSTATUS']._serialized_end=2598
  _globals['_SECURITYRULE']._serialized_start=2601
  _globals['_SECURITYRULE']._serialized_end=2861
  _globals['_SECURITYRULESPEC']._serialized_start=2864
  _globals['_SECURITYRULESPEC']._serialized_end=3012
  _globals['_SECURITYRULESTATUS']._serialized_start=3014
  _globals['_SECURITYRULESTATUS']._serialized_end=3034
  _globals['_SECURITYPROFILE']._serialized_start=3037
  _globals['_SECURITYPROFILE']._serialized_end=3315
  _globals['_SECURITYPROFILESPEC']._serialized_start=3318
  _globals['_SECURITYPROFILESPEC']._serialized_end=4070
  _globals['_SECURITYPROFILESTATUS']._serialized_start=4072
  _globals['_SECURITYPROFILESTATUS']._serialized_end=4095
  _globals['_POLICYLOOKUPMATCH']._serialized_start=4098
  _globals['_POLICYLOOKUPMATCH']._serialized_end=4523
  _globals['_SECURITYPOLICYLOOKUPREQUEST']._serialized_start=4526
  _globals['_SECURITYPOLICYLOOKUPREQUEST']._serialized_end=5050
  _globals['_SECURITYPOLICYLOOKUPREQUEST_VNICLOOKUPINFO']._serialized_start=4806
  _globals['_SECURITYPOLICYLOOKUPREQUEST_VNICLOOKUPINFO']._serialized_end=5035
  _globals['_POLICYLOOKUPRESULT']._serialized_start=5053
  _globals['_POLICYLOOKUPRESULT']._serialized_end=5373
# @@protoc_insertion_point(module_scope)
