# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: interface.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0finterface.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\xf2\x01\n\tInterface\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x41\n\x04spec\x18\x02 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.InterfaceSpecR\x04spec\x12G\n\x06status\x18\x03 \x01(\x0b\x32/.opi_api.network.cloud.v1alpha1.InterfaceStatusR\x06status:E\xea\x41\x42\n(opi_api.network.cloud.v1alpha1/interface\x12\x16interfaces/{interface}\"\xee\x04\n\rInterfaceSpec\x12\x12\n\x04ifid\x18\x01 \x01(\x05R\x04ifid\x12K\n\x0c\x61\x64min_status\x18\x02 \x01(\x0e\x32(.opi_api.network.cloud.v1alpha1.IfStatusR\x0b\x61\x64minStatus\x12M\n\x0buplink_spec\x18\x03 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.UplinkSpecH\x00R\nuplinkSpec\x12T\n\x0euplink_pc_spec\x18\x04 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.UplinkPCSpecH\x00R\x0cuplinkPcSpec\x12H\n\nl3_if_spec\x18\x05 \x01(\x0b\x32(.opi_api.network.cloud.v1alpha1.L3IfSpecH\x00R\x08l3IfSpec\x12Z\n\x10loopback_if_spec\x18\x06 \x01(\x0b\x32..opi_api.network.cloud.v1alpha1.LoopbackIfSpecH\x00R\x0eloopbackIfSpec\x12W\n\x0f\x63ontrol_if_spec\x18\x07 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.ControlIfSpecH\x00R\rcontrolIfSpec\x12N\n\x0chost_if_spec\x18\x08 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.HostIfSpecH\x00R\nhostIfSpecB\x08\n\x06ifinfo\"U\n\nUplinkSpec\x12\"\n\rport_name_ref\x18\x01 \x01(\tR\x0bportNameRef\x12#\n\rnative_vlanid\x18\x02 \x01(\x05R\x0cnativeVlanid\"c\n\x0cUplinkPCSpec\x12.\n\x13member_ifids_bitmap\x18\x01 \x01(\x04R\x11memberIfidsBitmap\x12#\n\rnative_vlanid\x18\x02 \x01(\x05R\x0cnativeVlanid\"\xfe\x01\n\x08L3IfSpec\x12 \n\x0cvpc_name_ref\x18\x01 \x01(\tR\nvpcNameRef\x12G\n\x06prefix\x18\x02 \x03(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixR\x06prefix\x12\"\n\rport_name_ref\x18\x03 \x01(\tR\x0bportNameRef\x12\x42\n\x05\x65ncap\x18\x04 \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.EncapR\x05\x65ncap\x12\x1f\n\x0bmac_address\x18\x05 \x01(\x0cR\nmacAddress\">\n\x0c\x42GPCommunity\x12\x10\n\x03\x61sn\x18\x01 \x01(\x05R\x03\x61sn\x12\x1c\n\tcommunity\x18\x02 \x01(\x05R\tcommunity\"\xa9\x01\n\x0eLoopbackIfSpec\x12G\n\x06prefix\x18\x01 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixR\x06prefix\x12N\n\x0b\x63ommunities\x18\x02 \x03(\x0b\x32,.opi_api.network.cloud.v1alpha1.BGPCommunityR\x0b\x63ommunities\"y\n\rControlIfSpec\x12G\n\x06prefix\x18\x01 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixR\x06prefix\x12\x1f\n\x0bmac_address\x18\x02 \x01(\x0cR\nmacAddress\"\x93\x01\n\nHostIfSpec\x12\x0e\n\x02vf\x18\x01 \x01(\x08R\x02vf\x12<\n\x1a\x65nable_connection_tracking\x18\x02 \x01(\x08R\x18\x65nableConnectionTracking\x12\x1f\n\x0bmac_address\x18\x03 \x01(\x0cR\nmacAddress\x12\x16\n\x06ifname\x18\x04 \x01(\tR\x06ifname\"R\n\x0eUplinkIfStatus\x12\x1a\n\thw_if_idx\x18\x01 \x01(\x05R\x07hwIfIdx\x12$\n\x0ehw_port_number\x18\x02 \x01(\x05R\x0chwPortNumber\"*\n\x10LoopbackIfStatus\x12\x16\n\x06ifname\x18\x01 \x01(\tR\x06ifname\"\xa9\x01\n\x0cHostIfStatus\x12\x1e\n\x0bhw_if_idxes\x18\x01 \x03(\x0cR\thwIfIdxes\x12\x1f\n\x0bmac_address\x18\x02 \x01(\x0cR\nmacAddress\x12@\n\x06status\x18\x03 \x01(\x0e\x32(.opi_api.network.cloud.v1alpha1.IfStatusR\x06status\x12\x16\n\x06ifname\x18\x04 \x01(\tR\x06ifname\"\x97\x03\n\x0fInterfaceStatus\x12\x19\n\x08if_index\x18\x01 \x01(\rR\x07ifIndex\x12I\n\x0boper_status\x18\x02 \x01(\x0e\x32(.opi_api.network.cloud.v1alpha1.IfStatusR\noperStatus\x12Z\n\x10uplink_if_status\x18\x03 \x01(\x0b\x32..opi_api.network.cloud.v1alpha1.UplinkIfStatusH\x00R\x0euplinkIfStatus\x12`\n\x12loopback_if_status\x18\x04 \x01(\x0b\x32\x30.opi_api.network.cloud.v1alpha1.LoopbackIfStatusH\x00R\x10loopbackIfStatus\x12T\n\x0ehost_if_status\x18\x05 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.HostIfStatusH\x00R\x0chostIfStatusB\n\n\x08ifstatus*\x99\x01\n\x06IfType\x12\x17\n\x13IF_TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0eIF_TYPE_UPLINK\x10\x01\x12\x15\n\x11IF_TYPE_UPLINK_PC\x10\x02\x12\x0e\n\nIF_TYPE_L3\x10\x03\x12\x14\n\x10IF_TYPE_LOOPBACK\x10\x04\x12\x13\n\x0fIF_TYPE_CONTROL\x10\x05\x12\x10\n\x0cIF_TYPE_HOST\x10\x06*K\n\x08IfStatus\x12\x19\n\x15IF_STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cIF_STATUS_UP\x10\x01\x12\x12\n\x0eIF_STATUS_DOWN\x10\x02\x42o\n\x1eopi_api.network.cloud.v1alpha1B\x0eInterfaceProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'interface_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\016InterfaceProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_INTERFACE']._options = None
  _globals['_INTERFACE']._serialized_options = b'\352AB\n(opi_api.network.cloud.v1alpha1/interface\022\026interfaces/{interface}'
  _globals['_IFTYPE']._serialized_start=2633
  _globals['_IFTYPE']._serialized_end=2786
  _globals['_IFSTATUS']._serialized_start=2788
  _globals['_IFSTATUS']._serialized_end=2863
  _globals['_INTERFACE']._serialized_start=99
  _globals['_INTERFACE']._serialized_end=341
  _globals['_INTERFACESPEC']._serialized_start=344
  _globals['_INTERFACESPEC']._serialized_end=966
  _globals['_UPLINKSPEC']._serialized_start=968
  _globals['_UPLINKSPEC']._serialized_end=1053
  _globals['_UPLINKPCSPEC']._serialized_start=1055
  _globals['_UPLINKPCSPEC']._serialized_end=1154
  _globals['_L3IFSPEC']._serialized_start=1157
  _globals['_L3IFSPEC']._serialized_end=1411
  _globals['_BGPCOMMUNITY']._serialized_start=1413
  _globals['_BGPCOMMUNITY']._serialized_end=1475
  _globals['_LOOPBACKIFSPEC']._serialized_start=1478
  _globals['_LOOPBACKIFSPEC']._serialized_end=1647
  _globals['_CONTROLIFSPEC']._serialized_start=1649
  _globals['_CONTROLIFSPEC']._serialized_end=1770
  _globals['_HOSTIFSPEC']._serialized_start=1773
  _globals['_HOSTIFSPEC']._serialized_end=1920
  _globals['_UPLINKIFSTATUS']._serialized_start=1922
  _globals['_UPLINKIFSTATUS']._serialized_end=2004
  _globals['_LOOPBACKIFSTATUS']._serialized_start=2006
  _globals['_LOOPBACKIFSTATUS']._serialized_end=2048
  _globals['_HOSTIFSTATUS']._serialized_start=2051
  _globals['_HOSTIFSTATUS']._serialized_end=2220
  _globals['_INTERFACESTATUS']._serialized_start=2223
  _globals['_INTERFACESTATUS']._serialized_end=2630
# @@protoc_insertion_point(module_scope)
